<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns="http://www.w3.org/TR/xhtml1/strict">

<!-- __________________ MENSAJE CODECO I08________________________________ -->
<xsl:output  method="text" encoding="ISO-8859-1"/>

   <xsl:template match="/">
        <xsl:apply-templates select="//CODECOI08.HEADER"/>
        <xsl:apply-templates select="//CODECOI08.GROUP1"/>
        <xsl:apply-templates select="//CODECOI08.GROUP2"/>
        <xsl:apply-templates select="//CODECOI08.GROUP3"/>
        <xsl:apply-templates select="//CODECOI08.GROUP5"/>
        <xsl:apply-templates select="//CODECOI08.GROUP8"/>
               <!-- FIN DEL MENSAJE-->
        CODI08028^1^<xsl:value-of select="//CODECOI08.HEADER/anxs_message.header/anxe_message.reference.number"/>
    </xsl:template>

    <!-- CABECERA DEL MENSAJE-->
    <xsl:template match="CODECOI08.HEADER">

        <!-- Cabecera del envio-->
        <xsl:variable name="sender" select="anxs_interchange.header/anxe_sender.identification"/>
        <xsl:variable name="recipient" select="anxs_interchange.header/anxe_recipient.identification"/>

        ENV001^<xsl:value-of select="$sender"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$recipient"/>

        <!-- Segmento UNH-->
        <xsl:variable name="Nref" select="anxs_message.header/anxe_message.reference.number"/>

        CODI08000^<xsl:value-of select="$Nref"/>

        <!-- Segmento BGM-->
        <xsl:variable name="refMsg" select="trsd_beginning.of.message/tred_document.message.number"/>
        <xsl:variable name="funMsg" select="trsd_beginning.of.message/tred_message.function.coded"/>

        CODI08001^<xsl:value-of select="$refMsg"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$funMsg"/>

        <!-- Segmento DTM-->
        <xsl:variable name="dataDoc" select="trcd_date.time.period/tred_date.time.period"/>

        CODI08002^<xsl:value-of select="$dataDoc"/>

        <!-- Segmento FTX-->
        <xsl:for-each select="trsd_free.text">
        <xsl:variable name="txtQal" select="tred_text.subject.qualifier"/>
        <xsl:variable name="txtLibre" select="trcd_text.literal/tred_free.text"/>

        <xsl:if test="boolean($txtLibre[text()] or $txtQal[text()])">
                <xsl:if test="boolean($txtLibre[text()])">
                CODI08003^<xsl:value-of select="$txtQal"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$txtLibre"/>
                </xsl:if>
        </xsl:if>
        </xsl:for-each>
    </xsl:template>

   <!-- GRUPO 1: RFF -->
   <xsl:template match="CODECOI08.GROUP1">

        <!--Segmento RFF -->
        <xsl:for-each select="trcd_reference">
            <xsl:variable name="refQual" select="tred_reference.qualifier"/>
            <xsl:variable name="refNum" select="tred_reference.number"/>

            CODI08004^<xsl:value-of select="$refQual"/>
            <xsl:text>^</xsl:text><xsl:value-of select="$refNum"/>
        </xsl:for-each>

        </xsl:template>

        <!-- GRUPO 2: TDT -->
        <xsl:template match="CODECOI08.GROUP2">

        <!-- Segmento TDT-->
        <xsl:variable name="carrier" select="trsd_details.of.transport/trcd_carrier"/>
        <xsl:variable name="transportId" select="trsd_details.of.transport/trcd_transport.identification"/>

        CODI08005^<xsl:value-of select="trsd_details.of.transport/tred_conveyance.reference.number"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$carrier/tred_carrier.identification"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$carrier/tred_carrier.name"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$transportId/tred_id.of.the.means.of.transport"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$transportId/tred_id.of.means.of.transport.identification"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$transportId/tred_nationality.of.means.of.transport.coded"/>
   </xsl:template>

   <!-- GRUPO 3: NAD y Grupo 4 -->
   <xsl:template match="CODECOI08.GROUP3">
        <!-- Segmento NAD-->
        CODI08006^<xsl:value-of select="trsd_name.and.address/tred_party.qualifier"/>
        <xsl:text>^</xsl:text><xsl:value-of select="trsd_name.and.address/tred_party.id.identification"/>
        <xsl:text>^</xsl:text><xsl:value-of select="trsd_name.and.address/tred_name.and.address.line"/>
        <xsl:if test="boolean(trsd_name.and.address/tred_street.and.number.p.o.box[text()] or trsd_name.and.address/tred_city.name[text()] or trsd_name.and.address/tred_country.coded[text()])">
            <xsl:text>^</xsl:text><xsl:value-of select="trsd_name.and.address/tred_street.and.number.p.o.box"/>
        </xsl:if>
        <xsl:if test="boolean(trsd_name.and.address/tred_city.name[text()] or trsd_name.and.address/tred_country.coded[text()])">
            <xsl:text>^</xsl:text><xsl:value-of select="trsd_name.and.address/tred_city.name"/>
        </xsl:if>
        <xsl:if test="boolean(trsd_name.and.address/tred_country.coded[text()])">
            <xsl:text>^</xsl:text><xsl:value-of select="trsd_name.and.address/tred_country.coded"/>
        </xsl:if>

        <!-- GRUPO4: CTA y COM -->
        <xsl:if test="boolean(CODECOI08.GROUP4/trsd_contact.information  or CODECOI08.GROUP4/trcd_communication.contact)">
            <!-- Segmento CTA-->
            CODI08007^<xsl:value-of select="CODECOI08.GROUP4/trsd_contact.information/tred_department.or.employee.identification"/>
            <xsl:text>^</xsl:text><xsl:value-of select="CODECOI08.GROUP4/trsd_contact.information/tred_department.or.employee"/>

            <!-- Segmento COM-->
            <xsl:if test="CODECOI08.GROUP4/trcd_communication.contact">
                CODI08008^<xsl:value-of select="CODECOI08.GROUP4/trcd_communication.contact/tred_communication.number"/>
                <xsl:text>^</xsl:text><xsl:value-of select="CODECOI08.GROUP4/trcd_communication.contact/tred_communication.channel.qualifier"/>
            </xsl:if>
        </xsl:if>
   </xsl:template>

        <!-- GRUPO5 -->
        <xsl:template match="CODECOI08.GROUP5">
        <xsl:for-each select="self::CODECOI08.GROUP5">

            <!-- Segmento GID -->
            <xsl:variable name="numPartida" select="trsd_goods.item.details/tred_goods.item.number"/>
            <xsl:variable name="numBultos" select="trsd_goods.item.details/tred_number.of.packages"/>
            <xsl:variable name="tipoEmb" select="trsd_goods.item.details/tred_type.of.packages.identification"/>

            CODI08009^<xsl:value-of select="$numPartida"/>
            <xsl:text>^</xsl:text><xsl:value-of select="$numBultos"/>
            <xsl:text>^</xsl:text><xsl:value-of select="$tipoEmb"/>


            <!-- Segmento HAN -->
            <xsl:if test="boolean(trcd_handling.instructions/tred_handling.instructions.coded[text()] or trcd_handling.instructions/tred_handling.instructions[text()])">
                CODI08010^<xsl:value-of select="trcd_handling.instructions/tred_handling.instructions.coded"/>
                <xsl:if test="boolean(trcd_handling.instructions/tred_handling.instructions[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="trcd_handling.instructions/tred_handling.instructions"/>
                </xsl:if>
            </xsl:if>

            <!--Segmento FTX -->
            <xsl:variable name="calTxt" select="trsd_free.text/tred_text.subject.qualifier"/>
            <xsl:variable name="txtFree" select="trsd_free.text/trcd_text.literal/tred_free.text"/>

            CODI08011^<xsl:value-of select="$calTxt"/>
            <xsl:text>^</xsl:text><xsl:value-of select="$txtFree"/>

            <!-- Segmento MEA -->
            <xsl:for-each select="self::CODECOI08.GROUP5/trsd_measurements">
                CODI08012^<xsl:value-of select="tred_measurement.dimension.coded"/>
                <xsl:text>^</xsl:text>KGM<xsl:text>^</xsl:text>
                <xsl:value-of select="tred_measurement.value"/>
            </xsl:for-each>

            <!-- Segmento TMP -->
            <xsl:for-each select="self::CODECOI08.GROUP5/trcd_temperature.setting">
                CODI08013^<xsl:value-of select="tred_temperature.setting"/>
                <xsl:if test="boolean(tred_measure.unit.qualifier[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="tred_measure.unit.qualifier"/>
                </xsl:if>
            </xsl:for-each>

            <!-- Segmento SGP -->
            <xsl:for-each select="self::CODECOI08.GROUP5/trsd_split.goods.placement">
                CODI08014^<xsl:value-of select="tred_equipment.identification.number"/>
                <xsl:if test="boolean(tred_number.of.packages[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="tred_number.of.packages"/>
                </xsl:if>
            </xsl:for-each>

            <!-- GRUPO6 -->
            <xsl:for-each select="self::CODECOI08.GROUP5/CODECOI08.GROUP6">

                <xsl:variable name="imo" select="trsd_dangerous.goods/trcd_hazard.code/tred_hazard.code.identification"/>
                <xsl:variable name="imdg" select="trsd_dangerous.goods/trcd_hazard.code/tred_hazard.substance.item.page.number"/>
                <xsl:variable name="nVersion" select="trsd_dangerous.goods/trcd_hazard.code/tred_hazard.code.version.number"/>
                <xsl:variable name="undg" select="trsd_dangerous.goods/tred_undg.number"/>
                <xsl:variable name="packing" select="trsd_dangerous.goods/tred_packing.group.coded"/>
                <xsl:variable name="ems" select="trsd_dangerous.goods/tred_ems.number"/>
                <xsl:variable name="mfag" select="trsd_dangerous.goods/tred_mfag"/>
                <xsl:variable name="category" select="trsd_dangerous.goods/tred_category.of.means.of.transport.coded"/>

                <!-- Segmento DGS -->
                CODI08015^<xsl:value-of select="$imo"/>
                    <xsl:text>^</xsl:text><xsl:value-of select="$imdg"/>
                    <xsl:text>^</xsl:text><xsl:value-of select="$nVersion"/>
                    <xsl:text>^</xsl:text><xsl:value-of select="$undg"/>
                <xsl:if test="boolean($category[text()] or $mfag[text()] or $ems[text()] or $packing[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="$packing"/>
                </xsl:if>
                <xsl:if test="boolean($category[text()] or $mfag[text()] or $ems[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="$ems"/>
                </xsl:if>
                <xsl:if test="boolean($category[text()] or $mfag[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="$mfag"/>
                </xsl:if>
                <xsl:if test="boolean($category[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="$category"/>
                </xsl:if>

                <!-- Segmento FTX -->
                <xsl:for-each select="self::CODECOI08.GROUP6/trsd_free.text">
                    CODI08016^<xsl:value-of select="tred_text.subject.qualifier"/>
                    <xsl:text>^</xsl:text><xsl:value-of select="trcd_text.literal/tred_free.text"/>
                </xsl:for-each>
            </xsl:for-each>

        </xsl:for-each>
    </xsl:template>
    <!-- End Grupo 5 -->

        <!-- GRUPO 8 -->
        <xsl:template match="CODECOI08.GROUP8">
        <xsl:for-each select="self::CODECOI08.GROUP8">

            <!-- Segmento EQD -->
            <xsl:variable name="calEquip" select="trsd_equipment.details/tred_equipment.qualifier"/>
            <xsl:variable name="idEquip" select="trsd_equipment.details/tred_equipment.identification.number"/>
            <xsl:variable name="tipo" select="trsd_equipment.details/tred_equipment.size.and.type.identification"/>

            CODI08017^<xsl:value-of select="$calEquip"/>
            <xsl:text>^</xsl:text><xsl:value-of select="$idEquip"/>
            <xsl:if test="boolean($tipo[text()])">
                <xsl:text>^</xsl:text><xsl:value-of select="$tipo"/>
            </xsl:if>

            <!-- Segmento RFF -->
            CODI08018^<xsl:value-of select="trcd_reference/tred_reference.number"/>

            <!-- Segmento TMD -->
            <xsl:variable name="movCod" select="trcd_movement.type/tred_movement.type.coded"/>
            <xsl:variable name="mov" select="trcd_movement.type/tred_movement.type"/>

            <xsl:if test="boolean($mov[text()] or $movCod[text()])">
            CODI08019^<xsl:value-of select="$movCod"/>
                <xsl:if test="boolean($mov[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="$mov"/>
                </xsl:if>
            </xsl:if>

            <!-- Segmento MEA -->
            <xsl:variable name="meaCal" select="trsd_measurements/tred_measurement.dimension.coded"/>
            <xsl:variable name="meaVal" select="trsd_measurements/tred_measurement.value"/>

            <xsl:if test="boolean($meaCal[text()] or $meaVal[text()])">
                CODI08020^<xsl:value-of select="$meaCal"/>
                <xsl:text>^</xsl:text>KGM<xsl:text>^</xsl:text>
                <xsl:value-of select="$meaVal"/>
            </xsl:if>

            <!-- Segmento DIM -->
            <xsl:variable name="califMedida" select="trcd_dimensions/tred_measure.unit.qualifier"/>
            <xsl:variable name="largo" select="trcd_dimensions/tred_length.dimension"/>
            <xsl:variable name="ancho" select="trcd_dimensions/tred_width.dimension"/>
            <xsl:variable name="alto" select="trcd_dimensions/tred_height.dimension"/>

            <xsl:if test="boolean($califMedida[text()] or $largo[text()] or $ancho[text()] or $alto[text()])">
                CODI08021^<xsl:value-of select="$califMedida"/>
                <xsl:if test="boolean($largo[text()] or $ancho[text()] or $alto[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="$largo"/>
                </xsl:if>
                <xsl:if test="boolean($ancho[text()] or $alto[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="$ancho"/>
                </xsl:if>
                <xsl:if test="boolean($alto[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="$alto"/>
                </xsl:if>
            </xsl:if>

            <!-- Segmento SEL -->
            <xsl:if test="boolean(trsd_seal.number/tred_seal.number[text()])">
                CODI08022^<xsl:value-of select="trsd_seal.number/tred_seal.number"/>
            </xsl:if>

            <!-- Segmento FTX -->
            <xsl:for-each select="self::CODECOI08.GROUP8/trsd_free.text">
                CODI08023^<xsl:value-of select="tred_text.subject.qualifier"/>
                <xsl:text>^</xsl:text><xsl:value-of select="trcd_text.literal/tred_free.text"/>
            </xsl:for-each>

            <!-- GRUPO 9 -->
            <xsl:for-each select="self::CODECOI08.GROUP8/CODECOI08.GROUP9">

                <!-- Segmento DAM -->
                <xsl:variable name="peligroCod" select="trsd_damage/tred_type.of.damage.coded"/>
                <xsl:variable name="peligro" select="trsd_damage/tred_type.of.damage"/>
                <xsl:variable name="danoCod" select="trsd_damage/tred_damage.area.identification"/>
                <xsl:variable name="dano" select="trsd_damage/tred_damage.area"/>

                CODI08024^<xsl:value-of select="$peligroCod"/>
                <xsl:if test="boolean($dano[text()] or $danoCod[text()] or $peligro[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="$peligro"/>
                </xsl:if>
                <xsl:if test="boolean($dano[text()] or $danoCod[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="$danoCod"/>
                </xsl:if>
                <xsl:if test="boolean($dano[text()])">
                    <xsl:text>^</xsl:text><xsl:value-of select="$dano"/>
                </xsl:if>

                <!-- Segmento COD -->
                <xsl:variable name="unidadCod" select="trsd_component.details/tred_type.of.unit.component.coded"/>
                <xsl:variable name="unidad" select="trsd_component.details/tred_type.of.unit.component"/>
                <xsl:variable name="materialCod" select="trsd_component.details/tred_component.material.coded"/>
                <xsl:variable name="material" select="trsd_component.details/tred_component.material"/>

                <xsl:if test="boolean($material[text()] or $materialCod[text()] or $unidad[text()] or $unidadCod[text()])">
                    CODI08025^<xsl:value-of select="$unidadCod"/>
                    <xsl:if test="boolean($material[text()] or $materialCod[text()] or $unidad[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$unidad"/>
                    </xsl:if>
                    <xsl:if test="boolean($material[text()] or $materialCod[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$materialCod"/>
                    </xsl:if>
                    <xsl:if test="boolean($material[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$material"/>
                    </xsl:if>
                </xsl:if>
            </xsl:for-each>
            <!-- End Grupo 9 -->

            <!-- GRUPO 10 -->
            <xsl:for-each select="self::CODECOI08.GROUP8/CODECOI08.GROUP10">

                <!-- Segmento TDT -->


                <xsl:variable name="stQual" select="trsd_details.of.transport/tred_transport.stage.qualifier"/>

                <xsl:variable name="refNum" select="trsd_details.of.transport/tred_conveyance.reference.number"/>
                <xsl:variable name="trnsTerr" select="trsd_details.of.transport/tred_mode.of.transport.coded"/>
                <xsl:variable name="meansTrns" select="trsd_details.of.transport/trcd_transport.means/tred_type.of.means.of.transport.identification"/>
                <xsl:variable name="transportId" select="trsd_details.of.transport/trcd_transport.means/tred_type.of.means.of.transport"/>
                <xsl:variable name="carrierId" select="trsd_details.of.transport/trcd_carrier/tred_carrier.identification"/>
                <xsl:variable name="trnsName" select="trsd_details.of.transport/trcd_carrier/tred_carrier.name"/>
                <xsl:variable name="mtID" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.the.means.of.transport"/>

                CODI08026^<xsl:value-of select="$stQual"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$trnsTerr"/>
                <xsl:text>^</xsl:text>
                <xsl:if test="boolean($carrierId[text()])">
                    <xsl:value-of select="$carrierId"/>
                </xsl:if>
                <xsl:text>^</xsl:text>
                <xsl:if test="boolean($trnsName[text()])">
                    <xsl:value-of select="$trnsName"/>
                </xsl:if>
                <xsl:text>^</xsl:text><xsl:value-of select="$mtID"/>

                <!-- Segmento DTM -->
                CODI08027^<xsl:value-of select="trcd_date.time.period/tred_date.time.period"/>
            </xsl:for-each>
            <!-- End GRUPO 10 -->
        <!-- End del GRUPO 8 -->
        </xsl:for-each>
   </xsl:template>
</xsl:stylesheet>