<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/TR/xhtml1/strict">
	<xsl:import href="include.xsl"/>
	<xsl:output method="text" encoding="ISO-8859-1"/>
	<xsl:template match="/">
		<xsl:apply-templates select="//CODECOI08.HEADER"/>
		<xsl:call-template name="CODECOI08"/>
		<xsl:apply-templates select="//CODECOI08.GROUP2"/>
		<xsl:call-template name="GROUP3"/>
	</xsl:template>
	<xsl:template match="CODECOI08.HEADER">
		<!-- Definicion de variables y Xpath -->
		<xsl:variable name="EMISOR" select="anxs_interchange.header/anxe_sender.identification"/>
		<xsl:variable name="RECEPTOR" select="anxs_interchange.header/anxe_recipient.identification"/>
		<xsl:variable name="CAB_FECHA_EMISION" select="trcd_date.time.period/tred_date.time.period"/>
		<!-- variable que puede ser opcional -->
		<xsl:variable name="REF_INTERCAMBIO" select="anxs_interchange.header/anxe_application.reference"/>
		<xsl:variable name="CAB_RFF_LIBRE" select="anxs_message.header/anxe_message.reference.number"/>
		<xsl:variable name="CAB_ID_MENSAJE" select="trsd_beginning.of.message/tred_document.message.number"/>
		<xsl:variable name="CAB_FUNCION" select="trsd_beginning.of.message/tred_message.function.coded"/>
		<xsl:variable name="CAB_TXT_LUGAR_RECOGIDA" select="trsd_free.text/trcd_text.literal/tred_free.text"/>
		<!-- Formato de variables y orden -->
		<xsl:value-of select="$EMISOR"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$RECEPTOR"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$fechaActual"/>
		<xsl:if test="boolean(string-length($fechaActual) =0)">
			<xsl:call-template name="formateo">
				<xsl:with-param name="fecha" select="$CAB_FECHA_EMISION"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$REF_INTERCAMBIO"/>
		<xsl:if test="boolean(string-length($REF_INTERCAMBIO) =0)">-</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$CAB_RFF_LIBRE"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$CAB_ID_MENSAJE"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$CAB_FUNCION"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:call-template name="formateo">
			<xsl:with-param name="fecha" select="$CAB_FECHA_EMISION"/>
		</xsl:call-template>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$CAB_TXT_LUGAR_RECOGIDA"/>
		<xsl:if test="boolean(string-length($CAB_TXT_LUGAR_RECOGIDA) =0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:call-template name="camposVacios">
			<xsl:with-param name="i">1</xsl:with-param>
			<xsl:with-param name="count">4</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="CODECOI08">
		<xsl:for-each select="//CODECOI08/CODECOI08.GROUP1/trcd_reference">
			<xsl:choose>
				<xsl:when test="contains(tred_reference.qualifier,'AAJ')">
					<xsl:value-of select="tred_reference.number"/>
					<xsl:value-of select="$separadorColum"/>
				</xsl:when>
				<xsl:when test="contains(tred_reference.qualifier,'AAE')">
					<xsl:value-of select="tred_reference.number"/>
					<xsl:value-of select="$separadorColum"/>
				</xsl:when>
				<xsl:when test="contains(tred_reference.qualifier,'ER')">
					<xsl:value-of select="tred_reference.number"/>
					<xsl:value-of select="$separadorColum"/>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="CODECOI08.GROUP2">
		<!-- Definicion de variables y Xpath -->
		<xsl:variable name="TRANS_NUM_VIAJE" select="trsd_details.of.transport/tred_conveyance.reference.number"/>
		<xsl:variable name="TRANS_COD_LINEA" select="trsd_details.of.transport/trcd_carrier/tred_carrier.identification"/>
		<xsl:variable name="TRANS_NOM_LINEA" select="trsd_details.of.transport/trcd_carrier/tred_carrier.name"/>
		<xsl:variable name="TRANS_IMO" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.the.means.of.transport"/>
		<xsl:variable name="TRANS_NOMBRE" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.means.of.transport.identification"/>
		<xsl:variable name="TRANS_BANDERA" select="trsd_details.of.transport/trcd_transport.identification/tred_nationality.of.means.of.transport.coded"/>
		<!-- Formato de variables y orden -->
		<xsl:value-of select="$TRANS_NUM_VIAJE"/>
		<xsl:if test="boolean(string-length($TRANS_NUM_VIAJE)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$TRANS_COD_LINEA"/>
		<xsl:if test="boolean(string-length($TRANS_COD_LINEA)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$TRANS_NOM_LINEA"/>
		<xsl:if test="boolean(string-length($TRANS_NOM_LINEA)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$TRANS_IMO"/>
		<xsl:if test="boolean(string-length($TRANS_IMO)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$TRANS_NOMBRE"/>
		<xsl:if test="boolean(string-length($TRANS_NOMBRE)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$TRANS_BANDERA"/>
		<xsl:if test="boolean(string-length($TRANS_BANDERA)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
	</xsl:template>
	<xsl:template name="GROUP3">
		<xsl:variable name="grupo" select="//trsd_goods.item.details"/>
		<xsl:for-each select="//CODECOI08.GROUP3/trsd_name.and.address">
			<xsl:variable name="codigo" select="tred_party.qualifier"/>
			<xsl:choose>
				<xsl:when test="boolean(contains($codigo,'CN'))">
					<xsl:call-template name="CN"/>
				</xsl:when>
				<xsl:when test="boolean(contains($codigo,'GA')) or boolean(contains($codigo,'GA'))">
					<xsl:call-template name="RC"/>
					<xsl:call-template name="GRUPO4"/>
				</xsl:when>
				<xsl:when test="boolean(contains($codigo,'TR'))">
					<xsl:call-template name="TR"/>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="CN">
		<!-- Definicion de variables y Xpath -->
		<xsl:variable name="NAD_CN_NIF" select="tred_party.id.identification"/>
		<xsl:variable name="NAD_CN_NOMBRE_DIRECCION" select="tred_name.and.address.line"/>
		<xsl:variable name="NAD_CN_CALLE" select="tred_street.and.number.p.o.box"/>
		<xsl:variable name="NAD_CN_CIUDAD" select="tred_city.name"/>
		<xsl:variable name="NAD_CN_PAIS" select="tred_country.coded"/>
		<!-- Formato de variables y orden -->
		<xsl:value-of select="$NAD_CN_NIF"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_CN_NOMBRE_DIRECCION"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_CN_CALLE"/>
		<xsl:if test="boolean(string-length($NAD_CN_CALLE)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_CN_CIUDAD"/>
		<xsl:if test="boolean(string-length($NAD_CN_CIUDAD)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_CN_PAIS"/>
		<xsl:if test="boolean(string-length($NAD_CN_PAIS)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
	</xsl:template>
	<xsl:template name="TR">
		<!-- Antes de nada hay que comprobar si se han puesto datos del transportista. Si no hay que poner 10 columnas vacas -->
		<xsl:variable name="NADCAL2" select="//CODECOI08.GROUP3[2]/trsd_name.and.address/tred_party.qualifier"/>
		<xsl:if test="boolean(not(contains($NADCAL2,'GT'))) and boolean(not(contains($NADCAL2,'GA')))">
			<xsl:call-template name="camposVacios">
				<xsl:with-param name="i">1</xsl:with-param>
				<xsl:with-param name="count">10</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		
		<!-- Definicion de variables y Xpath -->
		<xsl:variable name="NAD_TR_NIF" select="tred_party.id.identification"/>
		<xsl:variable name="NAD_TR_NOMBRE_DIRECCION" select="tred_name.and.address.line"/>
		<xsl:variable name="NAD_TR_CALLE" select="tred_street.and.number.p.o.box"/>
		<xsl:variable name="NAD_TR_CIUDAD" select="tred_city.name"/>
		<xsl:variable name="NAD_TR_PAIS" select="tred_country.coded"/>
		<!-- Formato de variables y orden -->
		<xsl:value-of select="$NAD_TR_NIF"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_TR_NOMBRE_DIRECCION"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_TR_CALLE"/>
		<xsl:if test="boolean(string-length($NAD_TR_CALLE)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_TR_CIUDAD"/>
		<xsl:if test="boolean(string-length($NAD_TR_CIUDAD)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_TR_PAIS"/>
		<xsl:if test="boolean(string-length($NAD_TR_PAIS)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$saltoLinea"/>
	</xsl:template>
	<xsl:template name="RC">
		<!-- Definicion de variables y Xpath -->
		<xsl:variable name="NAD_RC_NIF" select="tred_party.id.identification"/>
		<xsl:variable name="NAD_RC_NOMBRE_DIRECCION" select="tred_name.and.address.line"/>
		<xsl:variable name="NAD_RC_CALIFICADOR" select="tred_party.qualifier"/>
		<xsl:variable name="NAD_RC_CALLE" select="tred_street.and.number.p.o.box"/>
		<xsl:variable name="NAD_RC_CIUDAD" select="tred_city.name"/>
		<xsl:variable name="NAD_RC_PAIS" select="tred_country.coded"/>
		<!-- Formato de variables y orden -->
		<xsl:value-of select="$NAD_RC_NIF"/>
		<xsl:if test="boolean(string-length($NAD_RC_NIF)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_NOMBRE_DIRECCION"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_CALIFICADOR"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_CALLE"/>
		<xsl:if test="boolean(string-length($NAD_RC_CALLE)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_CIUDAD"/>
		<xsl:if test="boolean(string-length($NAD_RC_CIUDAD)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_PAIS"/>
		<xsl:if test="boolean(string-length($NAD_RC_PAIS)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
	</xsl:template>
	<xsl:template name="GRUPO4">
		<!-- //CODECOI08.GROUP4 -->
		<!-- Definicion de variables y Xpath -->
		<xsl:variable name="NAD_RC_NIF_CONTACTO" select="//CODECOI08/CODECOI08.GROUP3/CODECOI08.GROUP4/trsd_contact.information/tred_department.or.employee.identification"/>
		<xsl:variable name="NAD_RC_PERSONA" select="//CODECOI08/CODECOI08.GROUP3/CODECOI08.GROUP4/trsd_contact.information/tred_department.or.employee"/>
		<xsl:variable name="NAD_RC_NUMERO" select="//CODECOI08/CODECOI08.GROUP3/CODECOI08.GROUP4/trcd_communication.contact/tred_communication.number"/>
		<xsl:variable name="NAD_RC_CANAL" select="//CODECOI08/CODECOI08.GROUP3/CODECOI08.GROUP4/trcd_communication.contact/tred_communication.channel.qualifier"/>
		<!-- Formato de variables y orden -->
		<xsl:value-of select="$NAD_RC_NIF_CONTACTO"/>
		<xsl:if test="boolean(string-length($NAD_RC_NIF_CONTACTO)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_PERSONA"/>
		<xsl:if test="boolean(string-length($NAD_RC_PERSONA)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_NUMERO"/>
		<xsl:if test="boolean(string-length($NAD_RC_NUMERO)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_CANAL"/>
		<xsl:if test="boolean(string-length($NAD_RC_CANAL)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
	</xsl:template>
</xsl:stylesheet>
