<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/TR/xhtml1/strict">
	<!--  stylesheet: http://xsltsl.sourceforge.net/xsl/stdlib.xsl -->
	<!--  http://www.w3.org/1999/XSL/Transform ____________________________________________ mensaje_CODECOI09I01 __________________________________________ -->
	<xsl:import href="include.xsl"/>
	<xsl:output method="text" encoding="ISO-8859-1"/>
	<xsl:template match="/">
		<xsl:apply-templates select="//CODECOI09.HEADER"/>
		<xsl:call-template name="CODECOI09"/>
		<xsl:call-template name="GROUP3"/>
	</xsl:template>
	<xsl:template match="CODECOI09.HEADER">
		<!-- Definicion de variables y Xpath -->
		<xsl:variable name="EMISOR" select="anxs_interchange.header/anxe_sender.identification"/>
		<xsl:variable name="RECEPTOR" select="anxs_interchange.header/anxe_recipient.identification"/>
		<xsl:variable name="CAB_FECHA_EMISION" select="trcd_date.time.period/tred_date.time.period"/>
		<!-- variable que puede ser opcional -->
		<xsl:variable name="REF_INTERCAMBIO" select="anxs_interchange.header/anxe_application.reference"/>
		<xsl:variable name="CAB_RFF_LIBRE" select="anxs_message.header/anxe_message.reference.number"/>
		<xsl:variable name="CAB_ID_MENSAJE" select="trsd_beginning.of.message/tred_document.message.number"/>
		<xsl:variable name="CAB_FUNCION" select="trsd_beginning.of.message/tred_message.function.coded"/>
		<!-- Formato de variables y orden -->
		<xsl:value-of select="$EMISOR"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$RECEPTOR"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$fechaActual"/>
		<xsl:if test="boolean(string-length($fechaActual) =0)">
			<xsl:call-template name="formateo">
				<xsl:with-param name="fecha" select="$CAB_FECHA_EMISION"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$REF_INTERCAMBIO"/>
		<xsl:if test="boolean(string-length($REF_INTERCAMBIO) =0)">-</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$CAB_RFF_LIBRE"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$CAB_ID_MENSAJE"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$CAB_FUNCION"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:call-template name="formateo">
			<xsl:with-param name="fecha" select="$CAB_FECHA_EMISION"/>
		</xsl:call-template>
		<xsl:value-of select="$separadorColum"/>
	</xsl:template>
	<xsl:template name="CODECOI09">
		<!-- Definicion de variables y Xpath -->
		<xsl:variable name="contador" select="count(//CODECOI09/CODECOI09.GROUP1)"/>
		<xsl:for-each select="//CODECOI09/CODECOI09.GROUP1">
			<xsl:variable name="NUM" select="trcd_reference/tred_reference.number"/>
		    	   <xsl:value-of select="$NUM"/>
					<xsl:value-of select="$separadorColum"/>
		</xsl:for-each>
		<xsl:call-template name="camposVacios">
			<xsl:with-param name="i" select="1"/>
			<xsl:with-param name="count" select="3-$contador"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="GROUP3">
		<xsl:variable name="grupo" select="//trsd_goods.item.details"/>
		<xsl:for-each select="//CODECOI09.GROUP3/trsd_name.and.address">
		<xsl:variable name="codigo" select="tred_party.qualifier"/>
			<xsl:choose>
				<xsl:when test="boolean(contains($codigo,'CN'))">
					<xsl:call-template name="CN"/>
				</xsl:when>
				<xsl:when test="boolean(contains($codigo,'GA')) or boolean(contains($codigo,'GT'))">
						<xsl:call-template name="RC"/>
						<xsl:call-template name="GRUPO4"/>
				</xsl:when>
				<xsl:when test="boolean(contains($codigo,'CR'))">
						<xsl:call-template name="CR"/>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="CN">
		<!-- Definicion de variables y Xpath -->
		<xsl:variable name="NAD_CN_NIF" select="tred_party.id.identification"/>
		<xsl:variable name="NAD_CN_NOMBRE_DIRECCION" select="tred_name.and.address.line"/>
		<xsl:variable name="NAD_CN_CALLE" select="tred_street.and.number.p.o.box"/>
		<xsl:variable name="NAD_CN_CIUDAD" select="tred_city.name"/>
		<xsl:variable name="NAD_CN_PAIS" select="tred_country.coded"/>
		<!-- Formato de variables y orden -->
		<xsl:value-of select="$NAD_CN_NIF"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_CN_NOMBRE_DIRECCION"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_CN_CALLE"/>
		<xsl:if test="boolean(string-length($NAD_CN_CALLE)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_CN_CIUDAD"/>
		<xsl:if test="boolean(string-length($NAD_CN_CIUDAD)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_CN_PAIS"/>
		<xsl:if test="boolean(string-length($NAD_CN_PAIS)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
	</xsl:template>
	<xsl:template name="CR">
		<!-- Definicion de variables y Xpath -->
		<xsl:variable name="NAD_CR_NIF" select="tred_party.id.identification"/>
		<xsl:variable name="NAD_CR_NOMBRE_DIRECCION" select="tred_name.and.address.line"/>
		<xsl:variable name="NAD_CR_CALLE" select="tred_street.and.number.p.o.box"/>
		<xsl:variable name="NAD_CR_CIUDAD" select="tred_city.name"/>
		<xsl:variable name="NAD_CR_PAIS" select="tred_country.coded"/>
		<!-- Formato de variables y orden -->
		<xsl:value-of select="$NAD_CR_NIF"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_CR_NOMBRE_DIRECCION"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_CR_CALLE"/>
		<xsl:if test="boolean(string-length($NAD_CR_CALLE)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_CR_CIUDAD"/>
		<xsl:if test="boolean(string-length($NAD_CR_CIUDAD)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_CR_PAIS"/>
		<xsl:if test="boolean(string-length($NAD_CR_PAIS)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$saltoLinea"/>
	</xsl:template>
	<xsl:template name="GRUPO4">
	<!-- //CODECOI09.GROUP4 -->
		<!-- Definicion de variables y Xpath -->
		<xsl:variable name="NAD_RC_NIF_CONTACTO" select="//CODECOI09/CODECOI09.GROUP3/CODECOI09.GROUP4/trsd_contact.information/tred_department.or.employee.identification"/>
		<xsl:variable name="NAD_RC_PERSONA" select="//CODECOI09/CODECOI09.GROUP3/CODECOI09.GROUP4/trsd_contact.information/tred_department.or.employee"/>
		<xsl:variable name="NAD_RC_NUMERO" select="//CODECOI09/CODECOI09.GROUP3/CODECOI09.GROUP4/trcd_communication.contact/tred_communication.number"/>
		<xsl:variable name="NAD_RC_CANAL" select="//CODECOI09/CODECOI09.GROUP3/CODECOI09.GROUP4/trcd_communication.contact/tred_communication.channel.qualifier"/>
		<!-- Formato de variables y orden -->
		<xsl:value-of select="$NAD_RC_NIF_CONTACTO"/>
		<xsl:if test="boolean(string-length($NAD_RC_NIF_CONTACTO)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_PERSONA"/>
		<xsl:if test="boolean(string-length($NAD_RC_PERSONA)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_NUMERO"/>
		<xsl:if test="boolean(string-length($NAD_RC_NUMERO)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_CANAL"/>
		<xsl:if test="boolean(string-length($NAD_RC_CANAL)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
	</xsl:template>
	<xsl:template name="RC">
		<!-- Definicion de variables y Xpath -->
		<xsl:variable name="NAD_RC_NIF" select="tred_party.id.identification"/>
		<xsl:variable name="NAD_RC_NOMBRE_DIRECCION" select="tred_name.and.address.line"/>
		<xsl:variable name="NAD_RC_CALIFICADOR" select="tred_party.qualifier"/>
		<xsl:variable name="NAD_RC_CALLE" select="tred_street.and.number.p.o.box"/>
		<xsl:variable name="NAD_RC_CIUDAD" select="tred_city.name"/>
		<xsl:variable name="NAD_RC_PAIS" select="tred_country.coded"/>
		<!-- Formato de variables y orden -->
		<xsl:value-of select="$NAD_RC_NIF"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_NOMBRE_DIRECCION"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_CALIFICADOR"/>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_CALLE"/>
		<xsl:if test="boolean(string-length($NAD_RC_CALLE)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_CIUDAD"/>
		<xsl:if test="boolean(string-length($NAD_RC_CIUDAD)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
		<xsl:value-of select="$NAD_RC_PAIS"/>
		<xsl:if test="boolean(string-length($NAD_RC_PAIS)=0)">
			<xsl:value-of select="$nullCharacter"/>
		</xsl:if>
		<xsl:value-of select="$separadorColum"/>
	</xsl:template>
</xsl:stylesheet>
