<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns="http://www.w3.org/TR/xhtml1/strict">

<!-- ___________________ mensaje_COPARNI04 ____________________________ -->

<xsl:output  method="text" encoding="ISO-8859-1"/>

   <xsl:template match="/">  
        <xsl:apply-templates select="//COPARNI04.HEADER"/>
        <xsl:apply-templates select="//COPARNI04.GROUP1"/>
        <xsl:apply-templates select="//COPARNI04.GROUP2"/>
        <xsl:apply-templates select="//COPARNI04.GROUP3"/>
        <xsl:apply-templates select="//COPARNI04.GROUP9"/>
        
        <!-- FIN DEL MENSAJE-->
        COPI04010^1^<xsl:value-of select="//COPARNI04.HEADER/anxs_message.header/anxe_message.reference.number"/>

   </xsl:template>

   <!-- CABECERA DEL MENSAJE-->
   <xsl:template match="COPARNI04.HEADER">
        <xsl:for-each select="self::COPARNI04.HEADER">
                <!-- Cabecera del envio-->
                <xsl:variable name="sender" select="anxs_interchange.header/anxe_sender.identification"/>
                <xsl:variable name="recipient" select="anxs_interchange.header/anxe_recipient.identification"/>

                ENV001<xsl:text>^</xsl:text>
                <xsl:value-of select="$sender"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$recipient"/>

                <!-- Segmento UNH-->
                <xsl:variable name="Nref" select="anxs_message.header/anxe_message.reference.number"/>

                COPI04000^<xsl:value-of select="$Nref"/>

                <!-- Segmento BGM-->
                <xsl:variable name="refMsg" select="trsd_beginning.of.message/tred_document.message.number"/>
                <xsl:variable name="funMsg" select="trsd_beginning.of.message/tred_message.function.coded"/>

                COPI04001<xsl:text>^</xsl:text>
                <xsl:value-of select="$refMsg"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$funMsg"/>

                <!-- Segmento DTM-->
                <xsl:variable name="dataDoc" select="trcd_date.time.period/tred_date.time.period"/>

                COPI04002^<xsl:value-of select="$dataDoc"/>

                <!-- Segmento FTX-->
                <xsl:for-each select="trsd_free.text">
                        <xsl:variable name="txtQual" select="tred_text.subject.qualifier"/>
                        <xsl:variable name="txtLit" select="trcd_text.literal/tred_free.text"/>

                        <xsl:if test="boolean($txtLit[text()])">
                        COPI04003<xsl:text>^</xsl:text>
                        <xsl:value-of select="$txtQual"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$txtLit"/>
                        </xsl:if>
                </xsl:for-each>

        </xsl:for-each>
   </xsl:template>
   <!-- /CABECERA DEL MENSAJE-->

   <!-- GRUPO1 -->
     <xsl:template match="COPARNI04.GROUP1">

        <xsl:for-each select="self::COPARNI04.GROUP1">
                <!--Segmento RFF -->
                <xsl:variable name="refQual" select="trcd_reference/tred_reference.qualifier"/>
                <xsl:variable name="refNum" select="trcd_reference/tred_reference.number"/>

                COPI04004<xsl:text>^</xsl:text>
                <xsl:value-of select="$refQual"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$refNum"/>

                <xsl:variable name="period" select="trcd_date.time.period/tred_date.time.period"/>

                <xsl:if test="boolean($period[text()])">
                COPI04005<xsl:text>^</xsl:text><xsl:value-of select="$period"/>
                </xsl:if>

        </xsl:for-each>
     </xsl:template>

   <!-- /GRUPO1-->

    <!-- GRUPO2 -->
     <xsl:template match="COPARNI04.GROUP2">

                <!-- Segmento TDT-->
                <xsl:variable name="transQual" select="trsd_details.of.transport/tred_transport.stage.qualifier"/>
                <xsl:variable name="refNum" select="trsd_details.of.transport/tred_mode.of.transport.coded"/>
                <xsl:variable name="codLinea" select="trsd_details.of.transport/trcd_carrier/tred_carrier.identification"/>
                <xsl:variable name="litLinea" select="trsd_details.of.transport/trcd_carrier/tred_carrier.name"/>

                COPI04006^<xsl:value-of select="$transQual"/>
                <xsl:if test="boolean($refNum[text()] or $codLinea[text()] or $litLinea[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$refNum"/>
                </xsl:if>
                <xsl:if test="boolean($codLinea[text()] or $litLinea[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$codLinea"/>
                </xsl:if>
                <xsl:if test="boolean($litLinea[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$litLinea"/>
                </xsl:if>

         </xsl:template>
   <!-- /GRUPO2-->

   <!-- GRUPO3 -->
     <xsl:template match="COPARNI04.GROUP3">

        <xsl:for-each select="self::COPARNI04.GROUP3">
                <!--Segmento NAD -->
                <xsl:variable name="partyQ" select="trsd_name.and.address/tred_party.qualifier"/>
                <xsl:variable name="partyId" select="trsd_name.and.address/tred_party.id.identification"/>
                <xsl:variable name="nomDir" select="trsd_name.and.address/tred_name.and.address.line"/>
                <xsl:variable name="calleAp" select="trsd_name.and.address/tred_street.and.number.p.o.box"/>
                <xsl:variable name="ciudad" select="trsd_name.and.address/tred_city.name"/>
                <xsl:variable name="pais" select="trsd_name.and.address/tred_country.coded"/>

                COPI04007<xsl:text>^</xsl:text>
                <xsl:value-of select="$partyQ"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$partyId"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$nomDir"/>
                <xsl:if test="boolean($calleAp[text()] or $ciudad[text()] or $pais[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$calleAp"/>
                </xsl:if>
                <xsl:if test="boolean($ciudad[text()] or $pais[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$ciudad"/>
                </xsl:if>
                <xsl:if test="boolean($pais[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$pais"/>
                </xsl:if>

        </xsl:for-each>

   </xsl:template>

   <!-- /GRUPO3-->

   <!-- GRUPO 9 -->
    <xsl:template match="COPARNI04.GROUP9">

      <xsl:for-each select="self::COPARNI04.GROUP9">

        <!-- Segmento EQD -->
        <xsl:variable name="eqCal" select="trsd_equipment.details/tred_equipment.qualifier"/>
        <xsl:variable name="eqID" select="trsd_equipment.details/tred_equipment.identification.number"/>
        <xsl:variable name="eqType" select="trsd_equipment.details/tred_equipment.size.and.type.identification"/>

        <xsl:choose>
                <xsl:when test="$eqCal[.='CN']">
                        COPI04008<xsl:text>^</xsl:text>
                        <xsl:value-of select="$eqCal"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$eqID"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$eqType"/>

                </xsl:when>
                <xsl:otherwise>
                        COPI04008<xsl:text>^</xsl:text>
                        <xsl:value-of select="$eqCal"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$eqID"/>
                        <xsl:if test="boolean($eqType[text()])">
                                <xsl:text>^</xsl:text><xsl:value-of select="$eqType"/>
                        </xsl:if>
                </xsl:otherwise>
        </xsl:choose>

        <!-- Segmento RFF -->

        <xsl:variable name="numCont" select="trcd_reference/tred_reference.number"/>
        <xsl:if test="trcd_reference">
                COPI04009^<xsl:value-of select="$numCont"/>
        </xsl:if>

     </xsl:for-each>
   </xsl:template>
   <!-- /GRUPO9-->
  </xsl:stylesheet>
