<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns="http://www.w3.org/TR/xhtml1/strict">

<!-- ______________________ mensaje_COPINOE04 ____________________________ -->

<xsl:output  method="text" encoding="ISO-8859-1"/>

   <xsl:template match="/">
        <xsl:apply-templates select="//COPINOE04.HEADER"/>
        <xsl:apply-templates select="//COPINOE04.GROUP1"/>
        <xsl:apply-templates select="//COPINOE04.GROUP2"/>
        <xsl:apply-templates select="//COPINOE04.GROUP3"/>
        <xsl:apply-templates select="//COPINOE04.GROUP8"/>

        <!-- FIN DEL MENSAJE-->
        COPE04013

   </xsl:template>

   <!-- CABECERA DEL MENSAJE-->
   <xsl:template match="COPINOE04.HEADER">

        <!-- Cabecera del envio-->
        <xsl:variable name="sender" select="anxs_interchange.header/anxe_sender.identification"/>
        <xsl:variable name="recipient" select="anxs_interchange.header/anxe_recipient.identification"/>

        ENV001<xsl:text>^</xsl:text>
        <xsl:value-of select="$sender"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$recipient"/>

        <!-- Segmento UNH-->
        <xsl:variable name="Nref" select="anxs_message.header/anxe_message.reference.number"/>

        COPE04000^<xsl:value-of select="$Nref"/>

        <!-- Segmento BGM-->
        <xsl:variable name="refMsg" select="trsd_beginning.of.message/tred_document.message.number"/>
        <xsl:variable name="funMsg" select="trsd_beginning.of.message/tred_message.function.coded"/>

        COPE04001<xsl:text>^</xsl:text>
        <xsl:value-of select="$refMsg"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$funMsg"/>

        <!-- Segmento DTM-->
        <xsl:variable name="dataDoc" select="trcd_date.time.period/tred_date.time.period"/>

        COPE04002^<xsl:value-of select="$dataDoc"/>

        <!-- Segmento FTX-->
        <xsl:for-each select="trsd_free.text">
                <xsl:variable name="txtQual" select="tred_text.subject.qualifier"/>
                <xsl:variable name="txtLit" select="trcd_text.literal/tred_free.text"/>

                <xsl:if test="boolean($txtLit[text()])">
                COPE04003<xsl:text>^</xsl:text>
                <xsl:value-of select="$txtQual"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$txtLit"/>
                </xsl:if>
        </xsl:for-each>

   </xsl:template>
   <!-- /CABECERA DEL MENSAJE-->

   <!-- GRUPO1 -->
     <xsl:template match="COPINOE04.GROUP1">

        <xsl:for-each select="self::COPINOE04.GROUP1">
                <!--Segmento RFF -->
                <xsl:variable name="refQual" select="trcd_reference/tred_reference.qualifier"/>
                <xsl:variable name="refNum" select="trcd_reference/tred_reference.number"/>

                COPE04004<xsl:text>^</xsl:text>
                <xsl:value-of select="$refQual"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$refNum"/>

                <!--Segmento DTM -->
                <xsl:variable name="period" select="trcd_date.time.period/tred_date.time.period"/>

                <xsl:if test="boolean($period[text()])">
                COPE04005<xsl:text>^</xsl:text><xsl:value-of select="$period"/>
                </xsl:if>

        </xsl:for-each>
     </xsl:template>

   <!-- /GRUPO1-->

   <!-- GRUPO2 -->
     <xsl:template match="COPINOE04.GROUP2">
        <!-- Segmento TDT-->
        <xsl:variable name="transCod" select="trsd_details.of.transport/tred_mode.of.transport.coded"/>
        <xsl:variable name="callSign" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.the.means.of.transport"/>
        <xsl:variable name="callSignLiteral" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.means.of.transport.identification"/>

        COPE04006
        <xsl:text>^</xsl:text><xsl:value-of select="$transCod"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$callSign"/>
        <xsl:if test="boolean($callSignLiteral[text()])">
                <xsl:text>^</xsl:text><xsl:value-of select="$callSignLiteral"/>
        </xsl:if>

        <!-- Segmento DTM-->
        <xsl:for-each select="trcd_date.time.period">
                <xsl:variable name="dataqual" select="tred_date.time.period.qualifier"/>
                <xsl:variable name="dataDoc" select="tred_date.time.period"/>

                COPE04007^<xsl:value-of select="$dataqual"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$dataDoc"/>
        </xsl:for-each>

   </xsl:template>

   <!-- /GRUPO2-->

   <!-- GRUPO3/GRUPO4 -->
     <xsl:template match="COPINOE04.GROUP3">

        <xsl:for-each select="self::COPINOE04.GROUP3">
                <!--Segmento NAD -->
                <xsl:variable name="partyQ" select="trsd_name.and.address/tred_party.qualifier"/>
                <xsl:variable name="partyId" select="trsd_name.and.address/tred_party.id.identification"/>
                <xsl:variable name="nomDir" select="trsd_name.and.address/tred_name.and.address.line"/>
                <xsl:variable name="calleAp" select="trsd_name.and.address/tred_street.and.number.p.o.box"/>
                <xsl:variable name="ciudad" select="trsd_name.and.address/tred_city.name"/>
                <xsl:variable name="pais" select="trsd_name.and.address/tred_country.coded"/>

                COPE04008<xsl:text>^</xsl:text>
                <xsl:value-of select="$partyQ"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$partyId"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$nomDir"/>
                <xsl:if test="boolean($calleAp[text()] or $ciudad[text()] or $pais[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$calleAp"/>
                </xsl:if>
                <xsl:if test="boolean($ciudad[text()] or $pais[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$ciudad"/>
                </xsl:if>
                <xsl:if test="boolean($pais[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$pais"/>
                </xsl:if>

                <!-- Segmento CTA-->
                <xsl:variable name="codeContact" select="COPINOE04.GROUP4/trsd_contact.information/tred_contact.function.coded"/>
                <xsl:variable name="trnsContact" select="COPINOE04.GROUP4/trsd_contact.information/tred_department.or.employee.identification"/>
                <xsl:variable name="perContact" select="COPINOE04.GROUP4/trsd_contact.information/tred_department.or.employee"/>

                <xsl:if test="boolean($codeContact[text()] or $trnsContact[text()] or $perContact[text()])">
                        COPE04009<xsl:text>^</xsl:text>
                        <xsl:value-of select="$codeContact"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$trnsContact"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$perContact"/>
                </xsl:if>

                <!-- Segmento COM-->
                <xsl:variable name="numCom" select="COPINOE04.GROUP4/trcd_communication.contact/tred_communication.number"/>
                <xsl:variable name="chanQual" select="COPINOE04.GROUP4/trcd_communication.contact/tred_communication.channel.qualifier"/>

                <xsl:if test="boolean($numCom[text()] or $chanQual[text()])">
                        COPE04010<xsl:text>^</xsl:text>
                        <xsl:value-of select="$numCom"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$chanQual"/>
                </xsl:if>

        </xsl:for-each>

   </xsl:template>

   <!-- /GRUPO3/GRUPO4-->

   <!-- GRUPO 8-->
     <xsl:template match="COPINOE04.GROUP8">
        <xsl:for-each select="self::COPINOE04.GROUP8">

        <!-- Segmento EQD -->
        <xsl:variable name="eqCal" select="trsd_equipment.details/tred_equipment.qualifier"/>
        <xsl:variable name="eqID" select="trsd_equipment.details/tred_equipment.identification.number"/>
        <xsl:variable name="equType" select="trsd_equipment.details/tred_equipment.size.and.type.identification"/>

        COPE04011<xsl:text>^</xsl:text>
        <xsl:value-of select="$eqCal"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$eqID"/>
        <xsl:if test="boolean($equType[text()])">
                <xsl:text>^</xsl:text><xsl:value-of select="$equType"/>
        </xsl:if>
        <!-- Segmento RFF -->

        <xsl:variable name="numCont" select="trcd_reference/tred_reference.number"/>
        <xsl:if test="trcd_reference">
                COPE04012^<xsl:value-of select="$numCont"/>
        </xsl:if>

      <!-- END FOR-EACH DEL GRUPO8 -->
      </xsl:for-each>

   </xsl:template>

   <!-- /GRUPO8-->

  </xsl:stylesheet>
