<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns="http://www.w3.org/TR/xhtml1/strict">

<!-- ____________________ mensaje_COPINOE05 _____________________________ -->

<xsl:output  method="text" encoding="ISO-8859-1"/>

   <xsl:template match="/">
        <xsl:apply-templates select="//COPINOE05.HEADER"/>
        <xsl:apply-templates select="//COPINOE05.GROUP1"/>
        <xsl:apply-templates select="//COPINOE05.GROUP2"/>
        <xsl:apply-templates select="//COPINOE05.GROUP3"/>
        <xsl:apply-templates select="//COPINOE05.GROUP5"/>
        <xsl:apply-templates select="//COPINOE05.GROUP8"/>

        <!-- FIN DEL MENSAJE-->
        COPE05020

   </xsl:template>

   <!-- CABECERA DEL MENSAJE-->
   <xsl:template match="COPINOE05.HEADER">

        <!-- Cabecera del envio-->
        <xsl:variable name="sender" select="anxs_interchange.header/anxe_sender.identification"/>
        <xsl:variable name="recipient" select="anxs_interchange.header/anxe_recipient.identification"/>

        ENV001<xsl:text>^</xsl:text>
        <xsl:value-of select="$sender"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$recipient"/>

        <!-- Segmento UNH-->
        <xsl:variable name="Nref" select="anxs_message.header/anxe_message.reference.number"/>

        COPE05000^<xsl:value-of select="$Nref"/>

        <!-- Segmento BGM-->
        <xsl:variable name="refMsg" select="trsd_beginning.of.message/tred_document.message.number"/>
        <xsl:variable name="funMsg" select="trsd_beginning.of.message/tred_message.function.coded"/>

        COPE05001<xsl:text>^</xsl:text>
        <xsl:value-of select="$refMsg"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$funMsg"/>

        <!-- Segmento DTM-->
        <xsl:variable name="dataDoc" select="trcd_date.time.period/tred_date.time.period"/>

        COPE05002^<xsl:value-of select="$dataDoc"/>

        <!-- Segmento FTX-->
        <xsl:for-each select="trsd_free.text">
                <xsl:variable name="txtQual" select="tred_text.subject.qualifier"/>
                <xsl:variable name="txtLit" select="trcd_text.literal/tred_free.text"/>

                <xsl:if test="boolean($txtLit[text()])">
                COPE05003<xsl:text>^</xsl:text>
                <xsl:value-of select="$txtQual"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$txtLit"/>
                </xsl:if>
        </xsl:for-each>

   </xsl:template>
   <!-- /CABECERA DEL MENSAJE-->

   <!-- GRUPO1 -->
     <xsl:template match="COPINOE05.GROUP1">

        <xsl:for-each select="self::COPINOE05.GROUP1">
                <!--Segmento RFF -->
                <xsl:variable name="refQual" select="trcd_reference/tred_reference.qualifier"/>
                <xsl:variable name="refNum" select="trcd_reference/tred_reference.number"/>

                COPE05004<xsl:text>^</xsl:text>
                <xsl:value-of select="$refQual"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$refNum"/>

        </xsl:for-each>
     </xsl:template>

   <!-- /GRUPO1-->

   <!-- GRUPO2 -->
     <xsl:template match="COPINOE05.GROUP2">
        <!-- Segmento TDT-->
        <xsl:variable name="transCod" select="trsd_details.of.transport/tred_mode.of.transport.coded"/>
        <xsl:variable name="callSign" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.the.means.of.transport"/>
        <xsl:variable name="nomBuque" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.means.of.transport.identification"/>

        COPE05005
        <xsl:text>^</xsl:text><xsl:value-of select="$transCod"/>
        <xsl:if test="boolean($callSign[text()] or $nomBuque[text()])">
                <xsl:text>^</xsl:text><xsl:value-of select="$callSign"/>
        </xsl:if>
        <xsl:if test="boolean($nomBuque[text()])">
                <xsl:text>^</xsl:text><xsl:value-of select="$nomBuque"/>
        </xsl:if>

        <!-- Segmento DTM-->
        <xsl:for-each select="trcd_date.time.period">
                <xsl:variable name="dataqual" select="tred_date.time.period.qualifier"/>
                <xsl:variable name="dataDoc" select="tred_date.time.period"/>

                COPE05006^<xsl:value-of select="$dataqual"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$dataDoc"/>
        </xsl:for-each>

   </xsl:template>

   <!-- /GRUPO2-->

   <!-- GRUPO3/GRUPO4 -->
     <xsl:template match="COPINOE05.GROUP3">

        <xsl:for-each select="self::COPINOE05.GROUP3">
                <!--Segmento NAD -->
                <xsl:variable name="partyQ" select="trsd_name.and.address/tred_party.qualifier"/>
                <xsl:variable name="partyId" select="trsd_name.and.address/tred_party.id.identification"/>
                <xsl:variable name="nomDir" select="trsd_name.and.address/tred_name.and.address.line"/>
                <xsl:variable name="calleAp" select="trsd_name.and.address/tred_street.and.number.p.o.box"/>
                <xsl:variable name="ciudad" select="trsd_name.and.address/tred_city.name"/>
                <xsl:variable name="pais" select="trsd_name.and.address/tred_country.coded"/>

                COPE05007<xsl:text>^</xsl:text>
                <xsl:value-of select="$partyQ"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$partyId"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$nomDir"/>
                <xsl:if test="boolean($calleAp[text()] or $ciudad[text()] or $pais[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$calleAp"/>
                </xsl:if>
                <xsl:if test="boolean($ciudad[text()] or $pais[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$ciudad"/>
                </xsl:if>
                <xsl:if test="boolean($pais[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$pais"/>
                </xsl:if>

                <!-- Segmento CTA-->
                <xsl:variable name="codeContact" select="COPINOE05.GROUP4/trsd_contact.information/tred_contact.function.coded"/>
                <xsl:variable name="trnsContact" select="COPINOE05.GROUP4/trsd_contact.information/tred_department.or.employee.identification"/>
                <xsl:variable name="perContact" select="COPINOE05.GROUP4/trsd_contact.information/tred_department.or.employee"/>

                <xsl:if test="boolean($codeContact[text()] or $trnsContact[text()] or $perContact[text()])">
                        COPE05008<xsl:text>^</xsl:text>
                        <xsl:value-of select="$codeContact"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$trnsContact"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$perContact"/>
                </xsl:if>

                <!-- Segmento COM-->
                <xsl:variable name="numCom" select="COPINOE05.GROUP4/trcd_communication.contact/tred_communication.number"/>
                <xsl:variable name="chanQual" select="COPINOE05.GROUP4/trcd_communication.contact/tred_communication.channel.qualifier"/>

                <xsl:if test="boolean($numCom[text()] or $chanQual[text()])">
                        COPE05009<xsl:text>^</xsl:text>
                        <xsl:value-of select="$numCom"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$chanQual"/>
                </xsl:if>

        </xsl:for-each>

   </xsl:template>

   <!-- /GRUPO3/GRUPO4-->

   <!-- GRUPO 5 y 6 -->
    <xsl:template match="COPINOE05.GROUP5">

        <xsl:for-each select="self::COPINOE05.GROUP5">

        <!-- Segmento GID -->
        <xsl:variable name="numPartida" select="trsd_goods.item.details/tred_goods.item.number"/>
        <xsl:variable name="numBultos" select="trsd_goods.item.details/tred_number.of.packages"/>
        <xsl:variable name="tipoEmb" select="trsd_goods.item.details/tred_type.of.packages.identification"/>

           COPE05010<xsl:text>^</xsl:text>
           <xsl:value-of select="$numPartida"/>
           <xsl:text>^</xsl:text><xsl:value-of select="$numBultos"/>
           <xsl:text>^</xsl:text><xsl:value-of select="$tipoEmb"/>

        <!-- Segmento SGP -->
        <xsl:for-each select="trsd_split.goods.placement">
                <xsl:variable name="contNum" select="tred_equipment.identification.number"/>
                <xsl:variable name="numBultos" select="tred_number.of.packages"/>

                COPE05011<xsl:text>^</xsl:text>
                <xsl:value-of select="$contNum"/>
                <xsl:if test="boolean($numBultos[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$numBultos"/>
                </xsl:if>
        </xsl:for-each>

        <xsl:for-each select="self::COPINOE05.GROUP5/COPINOE05.GROUP6">

                <!-- Segmento DGS -->
                <xsl:variable name="clase" select="trsd_dangerous.goods/trcd_hazard.code/tred_hazard.code.identification"/>
                <xsl:variable name="pagIMDG" select="trsd_dangerous.goods/trcd_hazard.code/ tred_hazard.substance.item.page.number"/>
                <xsl:variable name="version" select="trsd_dangerous.goods/trcd_hazard.code/ tred_hazard.code.version.number"/>
                                <xsl:variable name="numONU" select="trsd_dangerous.goods/tred_undg.number"/>
                <xsl:variable name="packCode" select="trsd_dangerous.goods/tred_packing.group.coded"/>
                <xsl:variable name="numEMS" select="trsd_dangerous.goods/tred_ems.number"/>
                <xsl:variable name="mfag" select="trsd_dangerous.goods/tred_mfag"/>
                <xsl:variable name="catTrans" select="trsd_dangerous.goods/tred_category.of.means.of.transport.coded"/>

                COPE05012<xsl:text>^</xsl:text>
                <xsl:value-of select="$clase"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$pagIMDG"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$version"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$numONU"/>
                <xsl:if test="boolean($packCode[text()] or $numEMS[text()] or $mfag[text()] or $catTrans[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$packCode"/>
                </xsl:if>
                <xsl:if test="boolean($numEMS[text()] or $mfag[text()] or $catTrans[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$numEMS"/>
                </xsl:if>
                <xsl:if test="boolean($mfag[text()] or $catTrans[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$mfag"/>
                </xsl:if>
                <xsl:if test="boolean($catTrans[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$catTrans"/>
                </xsl:if>

                <!--Segmento FTX -->
                <xsl:for-each select="trsd_free.text">
                        <xsl:variable name="txtQual" select="tred_text.subject.qualifier"/>
                        <xsl:variable name="txtLit" select="trcd_text.literal/tred_free.text"/>

                        COPE05013<xsl:text>^</xsl:text>
                        <xsl:value-of select="$txtQual"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$txtLit"/>

                </xsl:for-each>
         <!--END FOR-EACH GRUPO 6-->
         </xsl:for-each>

     <!--END FOR-EACH GRUPO 5 Y 6-->
     </xsl:for-each>

   </xsl:template>

   <!-- /GRUPO5/GRUPO6-->

   <!-- GRUPO 8-->
     <xsl:template match="COPINOE05.GROUP8">
        <xsl:for-each select="self::COPINOE05.GROUP8">

        <!-- Segmento EQD -->
        <xsl:variable name="eqCal" select="trsd_equipment.details/tred_equipment.qualifier"/>
        <xsl:variable name="eqID" select="trsd_equipment.details/tred_equipment.identification.number"/>
        <xsl:variable name="eqtype" select="trsd_equipment.details/tred_equipment.size.and.type.identification"/>

        COPE05014<xsl:text>^</xsl:text>
        <xsl:value-of select="$eqCal"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$eqID"/>
        <xsl:if test="boolean($eqtype[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$eqtype"/>
        </xsl:if>


        <!-- Segmento RFF -->

        <xsl:variable name="numCont" select="trcd_reference/tred_reference.number"/>
        <xsl:if test="trcd_reference">
                COPE05015^<xsl:value-of select="$numCont"/>
        </xsl:if>

        <!-- Segmento MEA -->
        <xsl:variable name="dimcoded" select="trsd_measurements/tred_measurement.dimension.coded"/>
        <xsl:variable name="peso" select="trsd_measurements/tred_measurement.value"/>

        <xsl:if test="boolean($dimcoded[text()] or $peso[text()])">
                COPE05016<xsl:text>^</xsl:text>
                <xsl:value-of select="$dimcoded"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$peso"/>
        </xsl:if>

        <!-- Segmento DIM -->
        <xsl:variable name="unCal" select="trcd_dimensions/tred_measure.unit.qualifier"/>
        <xsl:variable name="largo" select="trcd_dimensions/tred_length.dimension"/>
        <xsl:variable name="ancho" select="trcd_dimensions/tred_width.dimension"/>
        <xsl:variable name="alto" select="trcd_dimensions/tred_height.dimension"/>

        <xsl:if test="boolean($unCal[text()] or $largo[text()] or $ancho[text()] or $alto[text()])">
                COPE05017<xsl:text>^</xsl:text>
                <xsl:value-of select="$unCal"/>
                <xsl:if test="boolean($largo[text()] or $ancho[text()] or $alto[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$largo"/>
                </xsl:if>
                <xsl:if test="boolean($ancho[text()] or $alto[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$ancho"/>
                </xsl:if>
                <xsl:if test="boolean($alto[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$alto"/>
                </xsl:if>
        </xsl:if>

        <!--Segmento FTX -->
        <xsl:for-each select="trsd_free.text">
                <xsl:variable name="txtQual" select="tred_text.subject.qualifier"/>
                <xsl:variable name="txtLit" select="trcd_text.literal/tred_free.text"/>

                COPE05018<xsl:text>^</xsl:text>
                <xsl:value-of select="$txtQual"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$txtLit"/>

        </xsl:for-each>

        <!-- Segmento SEL -->
        <xsl:variable name="precinto" select="trsd_seal.number/tred_seal.number"/>

        <xsl:if test="boolean($precinto[text()])">
                COPE05019^<xsl:value-of select="$precinto"/>
        </xsl:if>

      <!-- END FOR-EACH DEL GRUPO8 -->
      </xsl:for-each>
   </xsl:template>
   <!-- /GRUPO8-->

  </xsl:stylesheet>
