<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns="http://www.w3.org/TR/xhtml1/strict">

<!-- ________________ mensaje_COPINOI06 _____________________________ -->

<xsl:output  method="text" encoding="ISO-8859-1"/>

   <xsl:template match="/">
        <xsl:apply-templates select="//COPINOI06.HEADER"/>
        <xsl:apply-templates select="//COPINOI06.GROUP1"/>
        <xsl:apply-templates select="//COPINOI06.GROUP2"/>
        <xsl:apply-templates select="//COPINOI06.GROUP3"/>
        <xsl:apply-templates select="//COPINOI06.GROUP5"/>
        <xsl:apply-templates select="//COPINOI06.GROUP8"/>

        <!-- FIN DEL MENSAJE-->
        COPI06019

   </xsl:template>

   <!-- CABECERA DEL MENSAJE-->
   <xsl:template match="COPINOI06.HEADER">

        <!-- Cabecera del envio-->
        <xsl:variable name="sender" select="anxs_interchange.header/anxe_sender.identification"/>
        <xsl:variable name="recipient" select="anxs_interchange.header/anxe_recipient.identification"/>

        ENV001^<xsl:value-of select="$sender"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$recipient"/>

        <!-- Segmento UNH-->
        <xsl:variable name="Nref" select="anxs_message.header/anxe_message.reference.number"/>

        COPI06000^<xsl:value-of select="$Nref"/>

        <!-- Segmento BGM-->
        <xsl:variable name="refMsg" select="trsd_beginning.of.message/tred_document.message.number"/>
        <xsl:variable name="funMsg" select="trsd_beginning.of.message/tred_message.function.coded"/>

        COPI06001^<xsl:value-of select="$refMsg"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$funMsg"/>

        <!-- Segmento DTM-->
        <xsl:variable name="dataDoc" select="trcd_date.time.period/tred_date.time.period"/>

        COPI06002^<xsl:value-of select="$dataDoc"/>

        <!-- Segmento FTX-->
        <xsl:for-each select="trsd_free.text">
                <xsl:variable name="txtQual" select="tred_text.subject.qualifier"/>
                <xsl:variable name="txtLit" select="trcd_text.literal/tred_free.text"/>

                <xsl:if test="boolean($txtLit[text()])">
                COPI06003^<xsl:value-of select="$txtQual"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$txtLit"/>
                </xsl:if>
        </xsl:for-each>

   </xsl:template>
   <!-- /CABECERA DEL MENSAJE-->

   <!-- GRUPO1 -->
        <xsl:template match="COPINOI06.GROUP1">

        <xsl:for-each select="self::COPINOI06.GROUP1">

                <!--Segmento RFF -->
                <xsl:variable name="refQual" select="trcd_reference/tred_reference.qualifier"/>
                <xsl:variable name="refNum" select="trcd_reference/tred_reference.number"/>

                COPI06004^<xsl:value-of select="$refQual"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$refNum"/>

                <!-- Segmento DTM -->
                <xsl:variable name="perqual" select="trcd_date.time.period/tred_date.time.period.qualifier"/>
                <xsl:variable name="period" select="trcd_date.time.period/tred_date.time.period"/>

                <xsl:if test="boolean($perqual[text()] or $period[text()])">
                        COPI06005^<xsl:value-of select="$perqual"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$period"/>
                </xsl:if>

        </xsl:for-each>
        </xsl:template>
   <!-- /GRUPO1-->


   <!-- GRUPO2 -->
        <xsl:template match="COPINOI06.GROUP2">
        <!-- Segmento TDT-->
        <xsl:variable name="transCod" select="trsd_details.of.transport/tred_mode.of.transport.coded"/>
        <xsl:variable name="callSign" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.the.means.of.transport"/>
        <xsl:variable name="nomBuque" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.means.of.transport.identification"/>
        
        COPI06006
        <xsl:text>^</xsl:text><xsl:value-of select="$transCod"/>
        <xsl:if test="boolean($callSign[text()] or $nomBuque[text()])">
                <xsl:text>^</xsl:text><xsl:value-of select="$callSign"/>
        </xsl:if>
        <xsl:if test="boolean($nomBuque[text()])">
                <xsl:text>^</xsl:text><xsl:value-of select="$nomBuque"/>
        </xsl:if>
        

        <!-- Segmento DTM-->
        <xsl:variable name="dataqual" select="trcd_date.time.period/tred_date.time.period.qualifier"/>
        <xsl:variable name="dataDoc" select="trcd_date.time.period/tred_date.time.period"/>

        COPI06007^<xsl:value-of select="$dataqual"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$dataDoc"/>
        

   </xsl:template>
   <!-- /GRUPO2-->


   <!-- GRUPO3/GRUPO4 -->
        <xsl:template match="COPINOI06.GROUP3">

        <xsl:for-each select="self::COPINOI06.GROUP3">
                <!--Segmento NAD -->
                <xsl:variable name="partyQ" select="trsd_name.and.address/tred_party.qualifier"/>
                <xsl:variable name="partyId" select="trsd_name.and.address/tred_party.id.identification"/>
                <xsl:variable name="nomDir" select="trsd_name.and.address/tred_name.and.address.line"/>
                <xsl:variable name="calleAp" select="trsd_name.and.address/tred_street.and.number.p.o.box"/>
                <xsl:variable name="ciudad" select="trsd_name.and.address/tred_city.name"/>
                <xsl:variable name="pais" select="trsd_name.and.address/tred_country.coded"/>

                COPI06008^<xsl:value-of select="$partyQ"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$partyId"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$nomDir"/>
                <xsl:if test="boolean($calleAp[text()] or $ciudad[text()] or $pais[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$calleAp"/>
                </xsl:if>
                <xsl:if test="boolean($ciudad[text()] or $pais[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$ciudad"/>
                </xsl:if>
                <xsl:if test="boolean($pais[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$pais"/>
                </xsl:if>

                <!-- Segmento CTA-->
                <xsl:variable name="codeContact" select="COPINOI06.GROUP4/trsd_contact.information/tred_contact.function.coded"/>
                <xsl:variable name="trnsContact" select="COPINOI06.GROUP4/trsd_contact.information/tred_department.or.employee.identification"/>
                <xsl:variable name="perContact" select="COPINOI06.GROUP4/trsd_contact.information/tred_department.or.employee"/>

                <xsl:if test="boolean($codeContact[text()] or $trnsContact[text()] or $perContact[text()])">
                        COPI06009^<xsl:value-of select="$codeContact"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$trnsContact"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$perContact"/>
                </xsl:if>

                <!-- Segmento COM-->
                <xsl:variable name="numCom" select="COPINOI06.GROUP4/trcd_communication.contact/tred_communication.number"/>
                <xsl:variable name="chanQual" select="COPINOI06.GROUP4/trcd_communication.contact/tred_communication.channel.qualifier"/>

                <xsl:if test="boolean($numCom[text()] or $chanQual[text()])">
                        COPI06010^<xsl:value-of select="$numCom"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$chanQual"/>
                </xsl:if>

        </xsl:for-each>
   </xsl:template>
   <!-- /GRUPO3/GRUPO4-->


   <!-- GRUPO 5 y 6 -->
    <xsl:template match="COPINOI06.GROUP5">

        <xsl:for-each select="self::COPINOI06.GROUP5">

        <!-- Segmento GID -->
                <xsl:variable name="numPartida" select="trsd_goods.item.details/tred_goods.item.number"/>
                <xsl:variable name="numBultos" select="trsd_goods.item.details/tred_number.of.packages"/>
                <xsl:variable name="tipoEmb" select="trsd_goods.item.details/tred_type.of.packages.identification"/>

           COPI06011^<xsl:value-of select="$numPartida"/>
                <xsl:if test="boolean($numBultos[text()] or $tipoEmb[text()])">
                <xsl:text>^</xsl:text><xsl:value-of select="$numBultos"/>
                        <xsl:if test="boolean($tipoEmb[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$tipoEmb"/>
                        </xsl:if>
                </xsl:if>

        <!-- Segmento SGP -->
        <xsl:for-each select="trsd_split.goods.placement">
                <xsl:variable name="contNum" select="tred_equipment.identification.number"/>
                <xsl:variable name="numBultos" select="tred_number.of.packages"/>

                COPI06012^<xsl:value-of select="$contNum"/>
                <xsl:if test="boolean($numBultos[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$numBultos"/>
                </xsl:if>
        </xsl:for-each>

        <xsl:for-each select="self::COPINOI06.GROUP5/COPINOI06.GROUP6">

                <!-- Segmento DGS -->
                <xsl:variable name="clase" select="trsd_dangerous.goods/trcd_hazard.code/tred_hazard.code.identification"/>
                <xsl:variable name="pagIMDG" select="trsd_dangerous.goods/trcd_hazard.code/ tred_hazard.substance.item.page.number"/>
                <xsl:variable name="version" select="trsd_dangerous.goods/trcd_hazard.code/ tred_hazard.code.version.number"/>
                <xsl:variable name="numONU" select="trsd_dangerous.goods/tred_undg.number"/>
                <xsl:variable name="packCode" select="trsd_dangerous.goods/tred_packing.group.coded"/>
                <xsl:variable name="numEMS" select="trsd_dangerous.goods/tred_ems.number"/>
                <xsl:variable name="mfag" select="trsd_dangerous.goods/tred_mfag"/>
                <xsl:variable name="catTrans" select="trsd_dangerous.goods/tred_category.of.means.of.transport.coded"/>


                COPI06013^<xsl:value-of select="$clase"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$pagIMDG"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$version"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$numONU"/>
                <xsl:if test="boolean($packCode[text()] or $numEMS[text()] or $mfag[text()] or $catTrans[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$packCode"/>
                </xsl:if>
                <xsl:if test="boolean($numEMS[text()] or $mfag[text()] or $catTrans[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$numEMS"/>
                </xsl:if>
                <xsl:if test="boolean($mfag[text()] or $catTrans[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$mfag"/>
                </xsl:if>
                <xsl:if test="boolean($catTrans[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$catTrans"/>
                </xsl:if>


                <!--Segmento FTX -->
                <xsl:for-each select="trsd_free.text">
                        <xsl:variable name="txtQual" select="tred_text.subject.qualifier"/>
                        <xsl:variable name="txtLit" select="trcd_text.literal/tred_free.text"/>

                        COPI06014^<xsl:value-of select="$txtQual"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$txtLit"/>
                </xsl:for-each>
         <!--END FOR-EACH GRUPO 6-->

         </xsl:for-each>
    <!--END FOR-EACH GRUPO 5 Y 6-->

   </xsl:for-each>
   </xsl:template>
   <!-- /GRUPO5/GRUPO6-->

   <!-- GRUPO 8-->
        <xsl:template match="COPINOI06.GROUP8">
        <xsl:for-each select="self::COPINOI06.GROUP8">

        <!-- Segmento EQD -->
   <xsl:variable name="eqCal" select="trsd_equipment.details/tred_equipment.qualifier"/>
        <xsl:variable name="eqID" select="trsd_equipment.details/tred_equipment.identification.number"/>
        <xsl:variable name="tipoEq" select="trsd_equipment.details/tred_equipment.size.and.type.identification"/>

        <xsl:choose>
                <xsl:when test="$eqCal[.='CN']">
                        COPI06015^<xsl:value-of select="$eqCal"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$eqID"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$tipoEq"/>
                </xsl:when>
                <xsl:otherwise>
                        COPI06015^<xsl:value-of select="$eqCal"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$eqID"/>
                        <xsl:if test="boolean($tipoEq[text()])">
                                <xsl:text>^</xsl:text><xsl:value-of select="$tipoEq"/>
                        </xsl:if>
                </xsl:otherwise>
        </xsl:choose>

                
        <!-- Segmento RFF -->
        <xsl:variable name="numCont" select="trcd_reference/tred_reference.number"/>
        <xsl:if test="trcd_reference">
                COPI06016^<xsl:value-of select="$numCont"/>
        </xsl:if>

        <!--Segmento FTX -->
        <xsl:for-each select="trsd_free.text">
                <xsl:variable name="txtQual" select="tred_text.subject.qualifier"/>
                <xsl:variable name="txtLit" select="trcd_text.literal/tred_free.text"/>

                COPI06017^<xsl:value-of select="$txtQual"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$txtLit"/>
        </xsl:for-each>

        <!-- Segmento SEL -->
        <xsl:variable name="precinto" select="trsd_seal.number/tred_seal.number"/>

        <xsl:if test="boolean($precinto[text()])">
                COPI06018^<xsl:value-of select="$precinto"/>
        </xsl:if>

        <!-- END FOR-EACH DEL GRUPO8 -->
        </xsl:for-each>
        </xsl:template>
        <!-- /GRUPO8-->

</xsl:stylesheet>
