<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns="http://www.w3.org/TR/xhtml1/strict">

<!-- _______________ MENSAJE COREORI03 _____________________________ -->

<xsl:output  method="text" encoding="ISO-8859-1"/>

   <xsl:template match="/">
        <xsl:apply-templates select="//COREORI03.HEADER"/>
        <xsl:apply-templates select="//COREORI03.GROUP1"/>
        <xsl:apply-templates select="//COREORI03.GROUP2"/>
        <xsl:apply-templates select="//COREORI03.GROUP3"/>
        <xsl:apply-templates select="//COREORI03.GROUP5"/>
        <xsl:apply-templates select="//COREORI03.GROUP10"/>

        <!-- FIN DEL MENSAJE-->
        CORI03028

        </xsl:template>

        <!-- CABECERA DEL MENSAJE-->
        <xsl:template match="COREORI03.HEADER">

        <!-- Cabecera del envio-->
        <xsl:variable name="sender" select="anxs_interchange.header/anxe_sender.identification"/>
        <xsl:variable name="recipient" select="anxs_interchange.header/anxe_recipient.identification"/>

        ENV001^<xsl:value-of select="$sender"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$recipient"/>

        <!-- Segmento UNH-->
        <xsl:variable name="Nref" select="anxs_message.header/anxe_message.reference.number"/>

        CORI03000^<xsl:value-of select="$Nref"/>

        <!-- Segmento BGM-->
        <xsl:variable name="refMsg" select="trsd_beginning.of.message/tred_document.message.number"/>
        <xsl:variable name="funMsg" select="trsd_beginning.of.message/tred_message.function.coded"/>

        CORI03001^<xsl:value-of select="$refMsg"/>
        <xsl:text>^</xsl:text><xsl:value-of select="$funMsg"/>

        <!-- Segmento DTM-->
        <xsl:variable name="dataDoc" select="trcd_date.time.period/tred_date.time.period"/>

        CORI03002^<xsl:value-of select="$dataDoc"/>

        <!--Segmento FTX -->
        <xsl:for-each select="trsd_free.text">
                <xsl:if test="boolean(tred_text.subject.qualifier[text()] or trcd_text.literal[text()])">
                        <xsl:variable name="txtLit" select="trcd_text.literal/tred_free.text"/>
                        <xsl:if test="boolean($txtLit[text()])">
                        CORI03003^<xsl:value-of select="tred_text.subject.qualifier"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="trcd_text.literal"/>
                        </xsl:if>
                </xsl:if>
        </xsl:for-each>

   </xsl:template>


        <!-- GRUPO1-->
        <xsl:template match="COREORI03.GROUP1">

                <!-- Segmento RFF-->
                <xsl:for-each select="trcd_reference">
                        CORI03004^<xsl:value-of select="tred_reference.qualifier"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="tred_reference.number"/>
                </xsl:for-each>

                <!--Segmento DTM-->
                <xsl:for-each select="trcd_date.time.period">
                        CORI03005^<xsl:value-of select="tred_date.time.period.qualifier"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="tred_date.time.period"/>
                </xsl:for-each>

   </xsl:template>


        <!-- GRUPO2 -->
        <xsl:template match="COREORI03.GROUP2">

                <!-- Segmento TDT-->
                <xsl:variable name="codLinea" select="trsd_details.of.transport/trcd_carrier/tred_carrier.identification"/>
                <xsl:variable name="litLinea" select="trsd_details.of.transport/trcd_carrier/tred_carrier.name"/>
                <xsl:variable name="callSign" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.the.means.of.transport"/>
                <xsl:variable name="idTrns" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.means.of.transport.identification"/>
                <xsl:variable name="bandera" select="trsd_details.of.transport/trcd_transport.identification/tred_nationality.of.means.of.transport.coded"/>

                CORI03006^<xsl:value-of select="trsd_details.of.transport/tred_conveyance.reference.number"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$codLinea"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$litLinea"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$callSign"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$idTrns"/>
                <xsl:if test="boolean($bandera[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="$bandera"/>
                </xsl:if>

                <!-- Segmento LOC-->
                <xsl:variable name="locId" select="trcd_location.identification/tred_place.location.identification"/>
                <xsl:variable name="locPlace" select="trcd_location.identification/tred_place.location"/>

                <xsl:if test="boolean($locId[text()] or $locPlace[text()])">
                        CORI03007^<xsl:value-of select="$locId"/>
                        <xsl:if test="boolean($locPlace[text()])">
                                <xsl:text>^</xsl:text><xsl:value-of select="$locPlace"/>
                        </xsl:if>
                </xsl:if>

                <!-- Segmento DTM-->
                <xsl:if test="boolean(trcd_date.time.period/tred_date.time.period[text()])">
                        CORI03008^<xsl:value-of select="trcd_date.time.period/tred_date.time.period"/>
                </xsl:if>

   </xsl:template>


        <!-- GRUPO 3 -->
        <xsl:template match="COREORI03.GROUP3">
        <xsl:for-each select="self::COREORI03.GROUP3">

                <!-- Segmento NAD-->
                CORI03009^<xsl:value-of select="trsd_name.and.address/tred_party.qualifier"/>
                <xsl:text>^</xsl:text><xsl:value-of select="trsd_name.and.address/tred_party.id.identification"/>
                <xsl:text>^</xsl:text><xsl:value-of select="trsd_name.and.address/tred_name.and.address.line"/>
                <xsl:if test="boolean(trsd_name.and.address/tred_street.and.number.p.o.box[text()] or trsd_name.and.address/tred_city.name[text()] or trsd_name.and.address/tred_country.coded[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="trsd_name.and.address/tred_street.and.number.p.o.box"/>
                </xsl:if>
                <xsl:if test="boolean(trsd_name.and.address/tred_city.name[text()] or trsd_name.and.address/tred_country.coded[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="trsd_name.and.address/tred_city.name"/>
                </xsl:if>
                <xsl:if test="boolean(trsd_name.and.address/tred_country.coded[text()])">
                        <xsl:text>^</xsl:text><xsl:value-of select="trsd_name.and.address/tred_country.coded"/>
                </xsl:if>

                <!-- GRUPO4 -->
                <xsl:for-each select="self::COREORI03.GROUP3/COREORI03.GROUP4">

                        <!-- Segmento CTA -->
                        <xsl:variable name="contactCod" select="trsd_contact.information/tred_contact.function.coded"/>
                        <xsl:variable name="idDepEmp" select="trsd_contact.information/tred_department.or.employee.identification"/>
                        <xsl:variable name="depEmp" select="trsd_contact.information/tred_department.or.employee"/>
        
                        <xsl:if test="boolean($contactCod[text()] or $idDepEmp[text()] or $depEmp[text()])">
                                CORI03010^<xsl:value-of select="$contactCod"/>
                                <xsl:text>^</xsl:text><xsl:value-of select="$idDepEmp"/>
                                <xsl:text>^</xsl:text><xsl:value-of select="$depEmp"/>
                        </xsl:if>

                        <!-- Segmento COM -->
                        <xsl:for-each select="self::COREORI03.GROUP4/trcd_communication.contact">
                                <xsl:if test="boolean(tred_communication.number[text()] or tred_communication.channel.qualifier[text()])">
                                        CORI03011^<xsl:value-of select="tred_communication.number"/>
                                        <xsl:text>^</xsl:text><xsl:value-of select="tred_communication.channel.qualifier"/>
                                </xsl:if>
                        </xsl:for-each>
                </xsl:for-each>

                <xsl:if test="boolean(trsd_free.text/tred_text.subject.qualifier[text()] or trsd_free.text/trcd_text.literal[text()])">
                        CORI03012^<xsl:value-of select="trsd_free.text/tred_text.subject.qualifier"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="trsd_free.text/trcd_text.literal"/>
                </xsl:if>

        <!-- Cierre del Grupo 3-->
        </xsl:for-each>
        </xsl:template>


        <!-- GRUPO5 -->
        <xsl:template match="COREORI03.GROUP5">
        <xsl:for-each select="self::COREORI03.GROUP5">

                <!-- Segmento GID -->
                <xsl:variable name="numPartida" select="trsd_goods.item.details/tred_goods.item.number"/>
                <xsl:variable name="numBultos" select="trsd_goods.item.details/tred_number.of.packages"/>
                <xsl:variable name="tipoEmbalaje" select="trsd_goods.item.details/tred_type.of.packages.identification"/>

                CORI03013^<xsl:value-of select="$numPartida"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$numBultos"/>
                <xsl:text>^</xsl:text><xsl:value-of select="$tipoEmbalaje"/>

                <!-- Segmento HAN -->
                <xsl:if test="boolean(trcd_handling.instructions/tred_handling.instructions.coded[text()] or trcd_handling.instructions/tred_handling.instructions[text()])">
                        CORI03014^<xsl:value-of select="trcd_handling.instructions/tred_handling.instructions.coded"/>
                        <xsl:if test="boolean(trcd_handling.instructions/tred_handling.instructions[text()])">
                                <xsl:text>^</xsl:text><xsl:value-of select="trcd_handling.instructions/tred_handling.instructions"/>
                        </xsl:if>
                </xsl:if>

                <!--Segmento FTX -->
                <xsl:for-each select="self::COREORI03.GROUP5/trsd_free.text">
                        CORI03015^<xsl:value-of select="tred_text.subject.qualifier"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="trcd_text.literal"/>
                </xsl:for-each>

                <!-- Segmento MEA -->
                <xsl:for-each select="self::COREORI03.GROUP5/trsd_measurements">
                        CORI03016^<xsl:value-of select="tred_measurement.dimension.coded"/>
                        <xsl:text>^</xsl:text>
                        <xsl:text>^</xsl:text><xsl:value-of select="tred_measurement.value"/>
                </xsl:for-each>

                <!-- Segmento PCI -->
                <xsl:for-each select="self::COREORI03.GROUP5/trsd_package.identification">
                        <xsl:if test="boolean(tred_marking.instructions.coded[text()] or tred_shipping.marks[text()])">
                                CORI03017^<xsl:value-of select="tred_marking.instructions.coded"/>
                                <xsl:text>^</xsl:text><xsl:value-of select="tred_shipping.marks"/>
                        </xsl:if>
                </xsl:for-each>

                <!-- GRUPO7 -->

                <!-- Segmento SGP -->
                <xsl:for-each select="self::COREORI03.GROUP5/COREORI03.GROUP7">
                        <xsl:variable name="eqNumId" select="trsd_split.goods.placement/tred_equipment.identification.number"/>
                        <xsl:variable name="numPack" select="trsd_split.goods.placement/tred_number.of.packages"/>

                        <xsl:if test="boolean($eqNumId[text()] or $numPack[text()])">
                                CORI03018^<xsl:value-of select="$eqNumId"/>
                                <xsl:if test="boolean($numPack[text()])">
                                        <xsl:text>^</xsl:text><xsl:value-of select="$numPack"/>
                                </xsl:if>
                        </xsl:if>
                </xsl:for-each>


                <!-- GRUPO8 -->
                <xsl:for-each select="self::COREORI03.GROUP5/COREORI03.GROUP8">

                        <!-- Segmento DGS -->
                        <xsl:variable name="imo" select="trsd_dangerous.goods/trcd_hazard.code/tred_hazard.code.identification"/>
                        <xsl:variable name="imdg" select="trsd_dangerous.goods/trcd_hazard.code/tred_hazard.substance.item.page.number"/>
                        <xsl:variable name="nVersion" select="trsd_dangerous.goods/trcd_hazard.code/tred_hazard.code.version.number"/>
                        <xsl:variable name="undg" select="trsd_dangerous.goods/tred_undg.number"/>
                        <xsl:variable name="packing" select="trsd_dangerous.goods/tred_packing.group.coded"/>
                        <xsl:variable name="ems" select="trsd_dangerous.goods/tred_ems.number"/>
                        <xsl:variable name="mfag" select="trsd_dangerous.goods/tred_mfag"/>
                        <xsl:variable name="category" select="trsd_dangerous.goods/tred_category.of.means.of.transport.coded"/>

                        CORI03019^<xsl:value-of select="$imo"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$imdg"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$nVersion"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$undg"/>
                        <xsl:if test="boolean($category[text()] or $mfag[text()] or $ems[text()] or $packing[text()])">
                                <xsl:text>^</xsl:text><xsl:value-of select="$packing"/>
                        </xsl:if>
                        <xsl:if test="boolean($category[text()] or $mfag[text()] or $ems[text()])">
                                <xsl:text>^</xsl:text><xsl:value-of select="$ems"/>
                        </xsl:if>
                        <xsl:if test="boolean($category[text()] or $mfag[text()])">
                                <xsl:text>^</xsl:text><xsl:value-of select="$mfag"/>
                        </xsl:if>
                        <xsl:if test="boolean($category[text()])">
                                <xsl:text>^</xsl:text><xsl:value-of select="$category"/>
                        </xsl:if>

                        <!-- Segmento FTX -->
                        <xsl:for-each select="self::COREORI03.GROUP8/trsd_free.text">
                                <xsl:if test="boolean(tred_text.subject.qualifier[text()] or trcd_text.literal[text()])">
                                        CORI03020^<xsl:value-of select="tred_text.subject.qualifier"/>
                                        <xsl:text>^</xsl:text><xsl:value-of select="trcd_text.literal"/>
                                </xsl:if>
                        </xsl:for-each>

                </xsl:for-each>


        <!-- Cierre DEL GRUPO 5 -->
        </xsl:for-each>
   </xsl:template>


   <!-- GRUPO10 -->
        <xsl:template match="COREORI03.GROUP10">
        <xsl:for-each select="self::COREORI03.GROUP10">

                <!-- Segmento EQD -->
                <xsl:variable name="calEquip" select="trsd_equipment.details/tred_equipment.qualifier"/>
                <xsl:variable name="idEquip" select="trsd_equipment.details/tred_equipment.identification.number"/>
                <xsl:variable name="typoEquip" select="trsd_equipment.details/tred_equipment.size.and.type.identification"/>

                <!-- <xsl:if test="boolean($calEquip[text()] or $idEquip[text()] or $typoEquip[text()])"> -->
                <xsl:choose>
                        <xsl:when test="$calEquip[.='CN']">
                                CORI03021^<xsl:value-of select="$calEquip"/>
                                <xsl:text>^</xsl:text><xsl:value-of select="$idEquip"/>
                                <xsl:text>^</xsl:text><xsl:value-of select="$typoEquip"/>
                        </xsl:when>
                        <xsl:otherwise>
                                CORI03021^<xsl:value-of select="$calEquip"/>
                                <xsl:text>^</xsl:text><xsl:value-of select="$idEquip"/>
                                <xsl:if test="boolean($typoEquip[text()])">
                                        <xsl:text>^</xsl:text><xsl:value-of select="$typoEquip"/>
                                </xsl:if>
                        </xsl:otherwise>
                </xsl:choose>

                <!-- Segmento RFF -->
                <xsl:if test="boolean(trcd_reference/tred_reference.number[text()])">
                        CORI03022^<xsl:value-of select="trcd_reference/tred_reference.number"/>
           </xsl:if>

                <!-- Segmento MEA -->
                <xsl:variable name="dimCod" select="trsd_measurements/tred_measurement.dimension.coded"/>
                <xsl:variable name="pesoCont" select="trsd_measurements/tred_measurement.value"/>

                <xsl:if test="boolean($dimCod[text()] or $pesoCont[text()])">
                        CORI03023^<xsl:value-of select="$dimCod"/>
                        <xsl:text>^</xsl:text>
                        <xsl:text>^</xsl:text><xsl:value-of select="$pesoCont"/>
                </xsl:if>

                <!-- Segmento DIM -->
                <xsl:variable name="calUnidad" select="trcd_dimensions/tred_measure.unit.qualifier"/>
                <xsl:variable name="largo" select="trcd_dimensions/tred_length.dimension"/>
                <xsl:variable name="ancho" select="trcd_dimensions/tred_width.dimension"/>
                <xsl:variable name="alto" select="trcd_dimensions/tred_height.dimension"/>

                <xsl:if test="boolean($calUnidad[text()] or $largo[text()] or $ancho[text()] or $alto[text()])">
                        CORI03024^<xsl:value-of select="$calUnidad"/>
                        <xsl:if test="boolean($largo[text()] or $ancho[text()] or $alto[text()])">
                                <xsl:text>^</xsl:text><xsl:value-of select="$largo"/>
                        </xsl:if>
                        <xsl:if test="boolean($ancho[text()] or $alto[text()])">
                                <xsl:text>^</xsl:text><xsl:value-of select="$ancho"/>
                        </xsl:if>
                        <xsl:if test="boolean($alto[text()])">
                                <xsl:text>^</xsl:text><xsl:value-of select="$alto"/>
                        </xsl:if>
                </xsl:if>

                <!-- Segmento TMP -->
                <xsl:variable name="tempMin" select="trcd_range/tred_range.minimum"/>
                <xsl:variable name="tempMax" select="trcd_range/tred_range.maximum"/>
                <xsl:variable name="tempCalif" select="trcd_range/tred_measure.unit.qualifier"/>

                <xsl:if test="boolean($tempMin[text()] or $tempMax[text()] or $tempCalif[text()])">
                        CORI03025^<xsl:value-of select="$tempMin"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$tempMax"/>
                        <xsl:text>^</xsl:text><xsl:value-of select="$tempCalif"/>
                </xsl:if>

                <!-- Segmento SEL -->
                <xsl:if test="boolean(trsd_seal.number/tred_seal.number[text()])">
                        CORI03026^<xsl:value-of select="trsd_seal.number/tred_seal.number"/>
                </xsl:if>

                <!-- Segmento FTX -->
                <xsl:for-each select="self::COREORI03.GROUP10/trsd_free.text">
                        <xsl:if test="boolean(tred_text.subject.qualifier[text()] or trcd_text.literal[text()])">
                                CORI03027^<xsl:value-of select="tred_text.subject.qualifier"/>
                                <xsl:text>^</xsl:text><xsl:value-of select="trcd_text.literal"/>
                        </xsl:if>
                </xsl:for-each>

        </xsl:for-each>
   </xsl:template>
   <!-- /GRUPO10 -->

</xsl:stylesheet>