<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
			      xmlns="http://www.w3.org/TR/xhtml1/strict">

<!-- ______________________ mensaje_IFTFCCI02 __________________________ -->

<xsl:output  method="text" encoding="ISO-8859-1"/>

   <xsl:template match="/">
	<xsl:apply-templates select="//IFTFCCI02.HEADER"/>
	<xsl:apply-templates select="//IFTFCCI02.GROUP2"/>
	<xsl:apply-templates select="//IFTFCCI02.GROUP3"/>
	<xsl:apply-templates select="//IFTFCCI02.GROUP5"/>
	<xsl:apply-templates select="//IFTFCCI02.GROUP6"/>
	<xsl:apply-templates select="//IFTFCCI02.GROUP11"/>
	<xsl:apply-templates select="//IFTFCCI02.GROUP17"/>
	<xsl:apply-templates select="//IFTFCCI02.GROUP28"/>
	IFTI02039

   </xsl:template>

   <!-- CABECERA DEL ENVIO-->
   <xsl:template match="IFTFCCI02.HEADER">

	<!-- Cabecera del envio-->
        <xsl:variable name="sender" select="anxs_interchange.header/anxe_sender.identification"/>
        <xsl:variable name="recipient" select="anxs_interchange.header/anxe_recipient.identification"/>

	ENV001^<xsl:value-of select="$sender"/>
	<xsl:text>^</xsl:text><xsl:value-of select="$recipient"/>


   <!-- CABECERA DEL MENSAJE-->
   	<!-- Segmento UNH-->
   	<xsl:variable name="Nref" select="anxs_message.header/anxe_message.reference.number"/>

	IFTI02000^<xsl:value-of select="$Nref"/>

   	<!-- Segmento BGM-->
	<xsl:variable name="refMsg" select="trsd_beginning.of.message/tred_document.message.number"/>
	<xsl:variable name="funMsg" select="trsd_beginning.of.message/tred_message.function.coded"/>

	IFTI02001^<xsl:value-of select="$refMsg"/>
	<xsl:text>^</xsl:text><xsl:value-of select="$funMsg"/>

	<!-- Segmento DTM-->
	<xsl:variable name="dataDoc" select="trcd_date.time.period/tred_date.time.period"/>

	IFTI02002^<xsl:value-of select="$dataDoc"/>

	<!-- Segmento FTX-->
	<xsl:for-each select="trsd_free.text">
		<xsl:variable name="txtQal" select="tred_text.subject.qualifier"/>
		<xsl:variable name="txtLibre" select="trcd_text.literal/tred_free.text"/>

		IFTI02003^<xsl:value-of select="$txtQal"/>
		<xsl:if test="boolean($txtLibre[text()])">
	  		<xsl:text>^</xsl:text><xsl:value-of select="$txtLibre"/>
		</xsl:if>
	</xsl:for-each>

   </xsl:template>

    <!-- GRUPO2 -->
     <xsl:template match="IFTFCCI02.GROUP2">

	<!--Segmento RFF -->
	<xsl:variable name="refQual" select="trcd_reference/tred_reference.qualifier"/>
	<xsl:variable name="refNum" select="trcd_reference/tred_reference.number"/>

	IFTI02004<xsl:text>^</xsl:text>
	<xsl:value-of select="$refQual"/>
	<xsl:text>^</xsl:text><xsl:value-of select="$refNum"/>

     </xsl:template>

   <!-- /GRUPO2-->

   <!-- GRUPO3 -->
     <xsl:template match="IFTFCCI02.GROUP3">

	<!--Segmento MOA -->
	<xsl:variable name="monQual" select="trsd_monetary.amount/tred_monetary.amount.type.qualifier"/>
	<xsl:variable name="monAmount" select="trsd_monetary.amount/ tred_monetary.amount"/>
	<xsl:variable name="currQual" select="trsd_monetary.amount/tred_currency.coded"/>

	IFTI02005<xsl:text>^</xsl:text>
	<xsl:value-of select="$monQual"/>
	<xsl:if test="boolean($monAmount[text()] or $currQual[text()])">
		<xsl:text>^</xsl:text><xsl:value-of select="$monAmount"/>
	</xsl:if>
	<xsl:if test="boolean($currQual[text()])">
		<xsl:text>^</xsl:text><xsl:value-of select="$currQual"/>
	</xsl:if>

    </xsl:template>

   <!-- /GRUPO3-->

   <!-- GRUPO5 -->
     <xsl:template match="IFTFCCI02.GROUP5">

	<!--Segmento CUX -->
	<xsl:variable name="curQual" select="trsd_currencies/tred_currency.details.qualifier"/>
	<xsl:variable name="curCoded" select="trsd_currencies/tred_currency.coded"/>
	<xsl:variable name="curRate" select="trsd_currencies/tred_currency.rate.base"/>
	<xsl:variable name="exchRate" select="trsd_currencies/tred_rate.of.exchange"/>

	IFTI02006^<xsl:value-of select="$curQual"/>
	<xsl:if test="boolean($curCoded[text()] or $curRate[text()] or $exchRate[text()])">
		<xsl:text>^</xsl:text><xsl:value-of select="$curCoded"/>
	</xsl:if>
	<xsl:if test="boolean($curRate[text()] or $exchRate[text()])">
		<xsl:text>^</xsl:text><xsl:value-of select="$curRate"/>
	</xsl:if>
	<xsl:if test="boolean($exchRate[text()])">
		<xsl:text>^</xsl:text><xsl:value-of select="$exchRate"/>
	</xsl:if>

	<!-- Segmento DTM-->
	<xsl:variable name="dataQual" select="trcd_date.time.period/tred_date.time.period.qualifier"/>
	<xsl:variable name="dataDoc" select="trcd_date.time.period/tred_date.time.period"/>

	<xsl:if test="boolean($dataQual[text()] or $dataDoc[text()])">
		IFTI02007^<xsl:value-of select="$dataQual"/>
		<xsl:text>^</xsl:text><xsl:value-of select="$dataDoc"/>
	</xsl:if>

     </xsl:template>

   <!-- /GRUPO5-->

   <!-- GRUPO6/GRUPO8/GRUPO9/GRUPO10 -->
   <xsl:template match="IFTFCCI02.GROUP6">

		<!-- Segmento TCC -->
		<xsl:variable name="freightId" select="trsd_transport.charge.rate.calculations/tred_freight.and.charges.identification"/>
		<xsl:variable name="listQual" select="trsd_transport.charge.rate.calculations/tred_code.list.qualifier"/>
		<xsl:variable name="agencyCoded" select="trsd_transport.charge.rate.calculations/tred_code.list.responsible.agency.coded"/>
		<xsl:variable name="charges" select="trsd_transport.charge.rate.calculations/tred_freight.and.charges"/>
		<xsl:variable name="itemNumber" select="trsd_transport.charge.rate.calculations/tred_item.number"/>

		IFTI02008
		<xsl:if test="boolean($freightId[text()] or $listQual[text()] or $agencyCoded[text()] or $charges[text()]  or $itemNumber[text()])">
			<xsl:text>^</xsl:text><xsl:value-of select="$freightId"/>
		</xsl:if>
		<xsl:if test="boolean($listQual[text()] or $agencyCoded[text()] or $charges[text()]  or $itemNumber[text()])">
			<xsl:text>^</xsl:text><xsl:value-of select="$listQual"/>
		</xsl:if>
		<xsl:if test="boolean($agencyCoded[text()] or $charges[text()] or  $itemNumber[text()])">
			<xsl:text>^</xsl:text><xsl:value-of select="$agencyCoded"/>
		</xsl:if>
		<xsl:if test="boolean($charges[text()] or $itemNumber[text()])">
			<xsl:text>^</xsl:text><xsl:value-of select="$charges"/>
		</xsl:if>
		<xsl:if test="boolean($itemNumber[text()])">
			<xsl:text>^</xsl:text><xsl:value-of select="$itemNumber"/>
		</xsl:if>

	   	<!-- Segmento QTY -->
		<xsl:for-each select="trsd_quantity">

			<xsl:variable name="quantQual" select="tred_quantity.qualifier"/>
			<xsl:variable name="quantity" select="tred_quantity"/>
			<xsl:variable name="unitQual" select="tred_measure.unit.qualifier"/>

			IFTI02009<xsl:text>^</xsl:text>
			<xsl:value-of select="$quantQual"/>
			<xsl:text>^</xsl:text><xsl:value-of select="$quantity"/>
			<xsl:if test="boolean($unitQual[text()])">
			<xsl:text>^</xsl:text><xsl:value-of select="$unitQual"/>
			</xsl:if>
		</xsl:for-each>

	   	<!-- GRUPO 8 -->

		<!--Segmento MOA -->
		<xsl:for-each select="IFTFCCI02.GROUP8">
			<xsl:variable name="monQual" select="trsd_monetary.amount/tred_monetary.amount.type.qualifier"/>
			<xsl:variable name="monAmount" select="trsd_monetary.amount/tred_monetary.amount"/>
			<xsl:variable name="currQual" select="trsd_monetary.amount/tred_currency.coded"/>
			<xsl:variable name="status" select="trsd_monetary.amount/tred_status.coded"/>

			<xsl:if test="boolean($monQual[text()] or $monAmount[text()] or $currQual[text()] or $status[text()])">
				IFTI02010<xsl:text>^</xsl:text>
				<xsl:value-of select="$monQual"/>
				<xsl:if test="boolean($monAmount[text()] or $currQual[text()] or $status[text()])">
					<xsl:text>^</xsl:text><xsl:value-of select="$monAmount"/>
				</xsl:if>
				<xsl:if test="boolean($currQual[text()] or $status[text()])">
					<xsl:text>^</xsl:text><xsl:value-of select="$currQual"/>
				</xsl:if>
				<xsl:if test="boolean($status[text()])">
					<xsl:text>^</xsl:text><xsl:value-of select="$status"/>
				</xsl:if>

			</xsl:if>

			<!-- GRUPO 9  -->
			<!--Segmento CUX -->
			<xsl:for-each select="IFTFCCI02.GROUP9">
				<xsl:variable name="curQual" select="trsd_currencies/tred_currency.details.qualifier"/>
				<xsl:variable name="curCoded" select="trsd_currencies/tred_currency.coded"/>
				<xsl:variable name="curRate" select="trsd_currencies/tred_currency.rate.base"/>
				<xsl:variable name="exchRate" select="trsd_currencies/tred_rate.of.exchange"/>

				<xsl:if test="boolean($curQual[text()] or $curCoded[text()] or $curRate[text()] or $exchRate[text()] or IFTFCCI02.GROUP8/IFTFCCI02.GROUP9/trcd_date.time.period/tred_date.time.period[text()])">
					IFTI02011<xsl:text>^</xsl:text><xsl:value-of select="$curQual"/>
					<xsl:if test="boolean($curCoded[text()] or $curRate[text()] or $exchRate[text()])">
						<xsl:text>^</xsl:text><xsl:value-of select="$curCoded"/>
					</xsl:if>
					<xsl:if test="boolean($curRate[text()] or $exchRate[text()])">
						<xsl:text>^</xsl:text><xsl:value-of select="$curRate"/>
					</xsl:if>
					<xsl:if test="boolean($exchRate[text()])">
						<xsl:text>^</xsl:text><xsl:value-of select="$exchRate"/>
					</xsl:if>
				</xsl:if>

				<!-- Segmento DTM-->
				<xsl:variable name="dataQual" select="trcd_date.time.period/tred_date.time.period.qualifier"/>
				<xsl:variable name="dataDoc" select="trcd_date.time.period/tred_date.time.period"/>

				<xsl:if test="boolean($dataDoc[text()])">
					IFTI02012^<xsl:value-of select="$dataQual"/>
					<xsl:text>^</xsl:text><xsl:value-of select="$dataDoc"/>
				</xsl:if>
			</xsl:for-each>

		<!-- /GRUPO 9-->
		<!-- GRUPO 10  -->
			<!--Segmento TAX -->
			<xsl:for-each select="IFTFCCI02.GROUP10"> 
				<xsl:variable name="calTax" select="trsd_duty.tax.fee.details/tred_duty.tax.fee.function.qualifier"/>
				<xsl:variable name="codeTax" select="trsd_duty.tax.fee.details/tred_duty.tax.fee.type.coded"/>

				<xsl:if test="boolean($calTax[text()] or $codeTax[text()])">
					IFTI02013<xsl:text>^</xsl:text><xsl:value-of select="$calTax"/>
					<xsl:if test="boolean($codeTax[text()])">
						<xsl:text>^</xsl:text><xsl:value-of select="$codeTax"/>
					</xsl:if>
				</xsl:if>

				<!-- Segmento PCD-->
				<xsl:variable name="calPer" select="trcd_percentage.details/tred_percentage.qualifier"/>
				<xsl:variable name="percentage" select="trcd_percentage.details/tred_percentage"/>

				<xsl:if test="boolean($calPer[text()] or $percentage[text()])">
					IFTI02014<xsl:text>^</xsl:text><xsl:value-of select="$calPer"/>
					<xsl:if test="boolean($percentage[text()])">
						<xsl:text>^</xsl:text><xsl:value-of select="$percentage"/>
					</xsl:if>
				</xsl:if>
			</xsl:for-each>

		<!-- /GRUPO 10-->

		</xsl:for-each>	
		<!-- /GRUPO 8 -->

   </xsl:template>
   <!-- /GRUPO6 -->
   <!-- GROUP11/GROUP12-->
     <xsl:template match="IFTFCCI02.GROUP11">

		<!--Segmento NAD -->
		<xsl:variable name="partyQ" select="trsd_name.and.address/tred_party.qualifier"/>
		<xsl:variable name="partyId" select="trsd_name.and.address/tred_party.id.identification"/>
		<xsl:variable name="nomDir" select="trsd_name.and.address/tred_name.and.address.line"/>
		<xsl:variable name="calleAp" select="trsd_name.and.address/tred_street.and.number.p.o.box"/>
		<xsl:variable name="ciudad" select="trsd_name.and.address/tred_city.name"/>
		<xsl:variable name="pais" select="trsd_name.and.address/tred_country.coded"/>

		IFTI02015<xsl:text>^</xsl:text>
		<xsl:value-of select="$partyQ"/>
		<xsl:text>^</xsl:text><xsl:value-of select="$partyId"/>
		<xsl:text>^</xsl:text><xsl:value-of select="$nomDir"/>
		<xsl:if test="boolean($ciudad[text()] or $pais[text()] or $calleAp[text()])">
			<xsl:text>^</xsl:text><xsl:value-of select="$calleAp"/>
		</xsl:if>
		<xsl:if test="boolean($ciudad[text()] or $pais[text()])">
			<xsl:text>^</xsl:text><xsl:value-of select="$ciudad"/>
		</xsl:if>
		<xsl:if test="boolean($pais[text()])">
			<xsl:text>^</xsl:text><xsl:value-of select="$pais"/>
		</xsl:if>

		<!-- GROUP12-->
		<xsl:if test="IFTFCCI02.GROUP12">
			<!-- Segmento CTA-->
			<xsl:variable name="codContact" select="IFTFCCI02.GROUP12/trsd_contact.information/tred_contact.function.coded"/>
			<xsl:variable name="trnsContact" select="IFTFCCI02.GROUP12/trsd_contact.information/tred_department.or.employee.ientification"/>
			<xsl:variable name="perContact" select="IFTFCCI02.GROUP12/trsd_contact.information/tred_department.or.employee"/>

			IFTI02016<xsl:text>^</xsl:text><xsl:value-of select="$codContact"/>
				 <xsl:text>^</xsl:text><xsl:value-of select="$trnsContact"/>
			         <xsl:text>^</xsl:text><xsl:value-of select="$perContact"/>

			<!-- Segmento COM-->
			<xsl:if test="IFTFCCI02.GROUP12/trcd_communication.contact">
				IFTI02017<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP12/trcd_communication.contact/tred_communication.number"/>
				  <xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP12/trcd_communication.contact/tred_communication.channel.qualifier"/>
			</xsl:if>

		</xsl:if>
		<!--TANCO EL IF DEL GROUP12-->

   </xsl:template>
   <!-- /GRUP11 -->
   <!-- GROUP17 -->
   <!-- Segmento TDT-->
   <xsl:template match="IFTFCCI02.GROUP17">
		<xsl:variable name="numIni" select="trsd_details.of.transport/tred_transport.stage.qualifier"/>
		<xsl:variable name="numViaje" select="trsd_details.of.transport/tred_conveyance.reference.number"/>
		<xsl:variable name="codLinea" select="trsd_details.of.transport/tred_mode.of.transport.coded"/>
		<xsl:variable name="meaTrId" select="trsd_details.of.transport/trcd_carrier/tred_carrier.identification"/>
		<xsl:variable name="carName" select="trsd_details.of.transport/trcd_carrier/tred_carrier.name"/>
		<xsl:variable name="callSign" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.the.means.of.transport"/>
		<xsl:variable name="nomBuque" select="trsd_details.of.transport/trcd_transport.identification/tred_id.of.means.of.transport.identification"/>
		<xsl:variable name="paisBuque" select="trsd_details.of.transport/trcd_transport.identification/tred_nationality.of.means.of.transport.coded"/>

		IFTI02018<xsl:text>^</xsl:text><xsl:value-of select="$numIni"/>
		         <xsl:text>^</xsl:text><xsl:value-of select="$numViaje"/>
			 <xsl:text>^</xsl:text><xsl:value-of select="$codLinea"/>
			 <xsl:text>^</xsl:text><xsl:value-of select="$meaTrId"/>
			 <xsl:text>^</xsl:text><xsl:value-of select="$carName"/>
			 <xsl:text>^</xsl:text><xsl:value-of select="$callSign"/>
			 <xsl:text>^</xsl:text><xsl:value-of select="$nomBuque"/>
			 <xsl:text>^</xsl:text><xsl:value-of select="$paisBuque"/>

		<!-- Segmento DTM -->
   		<xsl:for-each select="trcd_date.time.period">

			IFTI02019<xsl:text>^</xsl:text><xsl:value-of select="tred_date.time.period.qualifier"/>
				 <xsl:text>^</xsl:text><xsl:value-of select="tred_date.time.period"/>

 		</xsl:for-each>

    </xsl:template>
    <!-- /GROUP17 -->

    <!-- GRUPO28 -->
   <xsl:template match="IFTFCCI02.GROUP28">

	<!-- Segmento CNI -->
	<xsl:variable name="seqNumber" select="trsd_consignment.information/tred_consolidation.item.number"/>
	<xsl:variable name="itemNumber" select="trsd_consignment.information/tred_document.message.number"/>

	IFTI02020^<xsl:value-of select="$seqNumber"/>
	<xsl:if test="boolean($itemNumber[text()])">
		  <xsl:text>^</xsl:text><xsl:value-of select="$itemNumber"/>
	</xsl:if>

	<!-- GROUP30 -->

    <!-- Segmento LOC -->
   	<xsl:for-each select="IFTFCCI02.GROUP30">
		<xsl:variable name="locQual" select="trcd_location.identification/tred_place.location.qualifier"/>
		<xsl:variable name="locId" select="trcd_location.identification/tred_place.location.identification"/>
		<xsl:variable name="location" select="trcd_location.identification/tred_place.location"/>

		IFTI02021<xsl:text>^</xsl:text><xsl:value-of select="$locQual"/>
		<xsl:text>^</xsl:text><xsl:value-of select="$locId"/>
		<xsl:text>^</xsl:text><xsl:value-of select="$location"/>
	</xsl:for-each>

 	<!-- /GROUP30 -->

    <!-- GROUP37 -->
   	<xsl:for-each select="IFTFCCI02.GROUP37">

		<!-- Segmento GID -->
   		<xsl:variable name="numPartida" select="trsd_goods.item.details/tred_goods.item.number"/>
		<xsl:variable name="numBultos" select="trsd_goods.item.details/tred_number.of.packages"/>
		<xsl:variable name="tipoEmb" select="trsd_goods.item.details/tred_type.of.packages.identification"/>

		IFTI02022<xsl:text>^</xsl:text><xsl:value-of select="$numPartida"/>
	   	<xsl:text>^</xsl:text><xsl:value-of select="$numBultos"/>
	   	<xsl:text>^</xsl:text><xsl:value-of select="$tipoEmb"/>

	   	<!-- Segmento HAN -->
		<xsl:if test="trcd_handling.instructions">
			IFTI02023
		  	<xsl:text>^</xsl:text><xsl:value-of select="trcd_handling.instructions/tred_handling.instructions.coded"/>
		  	<xsl:text>^</xsl:text><xsl:value-of select="trcd_handling.instructions/tred_handling.instructions"/>
		</xsl:if>

		<!-- Segmento TMP -->
		<xsl:for-each select="trsd_temperature">

			<xsl:variable name="calTemp" select="tred_temperature.qualifier"/>
			<xsl:variable name="temp" select="trcd_temperature.setting/tred_temperature.setting"/>
			<xsl:variable name="meaQuali" select="trcd_temperature.setting/tred_measure.unit.qualifier"/>

			IFTI02024^<xsl:value-of select="$calTemp"/>
			<xsl:if test="boolean($temp[text()] or $meaQuali[text()])">
				<xsl:text>^</xsl:text><xsl:value-of select="$temp"/>
			</xsl:if>
			<xsl:if test="boolean($meaQuali[text()])">
				 <xsl:text>^</xsl:text><xsl:value-of select="$meaQuali"/>
		 	</xsl:if>
		</xsl:for-each>

		<!-- Segmento TMD -->
		<xsl:variable name="movTypCo" select="trcd_movement.type/tred_movement.type.coded"/>
		<xsl:variable name="movTyp" select="trcd_movement.type/tred_movement.type"/>

		<xsl:if test="trcd_movement.type">
			IFTI02025
			<xsl:if test="boolean($movTypCo[text()] or $movTyp[text()])">
				<xsl:text>^</xsl:text><xsl:value-of select="$movTypCo"/>
			</xsl:if>
			<xsl:if test="boolean($movTyp[text()])">
				 <xsl:text>^</xsl:text><xsl:value-of select="$movTyp"/>
		 	</xsl:if>
		</xsl:if>

		<!-- Segmento PCI -->
   		<xsl:for-each select="trsd_package.identification">

			IFTI02026<xsl:text>^</xsl:text><xsl:value-of select="tred_marking.instructions.coded"/>
		  	<xsl:text>^</xsl:text><xsl:value-of select="tred_shipping.marks"/>

 		</xsl:for-each>

 		<!--Segmento FTX -->
   		<xsl:variable name="txtQual" select="trsd_free.text/tred_text.subject.qualifier"/>
   		<xsl:variable name="txtFree" select="trsd_free.text/trcd_text.literal/tred_free.text"/>

		IFTI02027<xsl:text>^</xsl:text><xsl:value-of select="$txtQual"/>
		<xsl:text>^</xsl:text><xsl:value-of select="$txtFree"/>

		<!-- Segmento SGP -->
   		<xsl:for-each select="trsd_split.goods.placement">

			IFTI02028<xsl:text>^</xsl:text><xsl:value-of select="tred_equipment.identification.number"/>
		  	<xsl:if test="tred_number.of.packages">
		  		<xsl:text>^</xsl:text><xsl:value-of select="tred_number.of.packages"/>
		  	</xsl:if>

 		</xsl:for-each>

		<!-- Segmento MEA -->

		IFTI02029<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP38/trsd_measurements/tred_measurement.application.qualifier"/>
		<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP38/trsd_measurements/tred_measurement.dimension.coded"/>
		<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP38/trsd_measurements/tred_measure.unit.qualifier"/>
		<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP38/trsd_measurements/tred_measurement.value"/>

		<!-- GRUPO41 -->

		<!--Segmento DGS -->

		<xsl:if test="IFTFCCI02.GROUP41/trsd_dangerous.goods">

			IFTI02030<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP41/trsd_dangerous.goods/trcd_hazard.code/tred_hazard.code.identification"/>
			<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP41/trsd_dangerous.goods/trcd_hazard.code/tred_hazard.substance.item.page.number"/>
	 		<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP41/trsd_dangerous.goods/trcd_hazard.code/tred_hazard.code.version.number"/>
			<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_undg.number"/>
			<xsl:if test="boolean(IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_packing.group.coded or IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_ems.number or IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_mfag or IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_category.of.means.of.transport.coded)">
				<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_packing.group.coded"/>
			</xsl:if>
			<xsl:if test="boolean(IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_ems.number or IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_mfag or IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_category.of.means.of.transport.coded)">
				<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_ems.number"/>
			</xsl:if>
			<xsl:if test="boolean(IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_mfag or IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_category.of.means.of.transport.coded)">
				<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_mfag"/>
			</xsl:if>
			<xsl:if test="boolean(IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_category.of.means.of.transport.coded)">
				<xsl:text>^</xsl:text><xsl:value-of select="IFTFCCI02.GROUP41/trsd_dangerous.goods/tred_category.of.means.of.transport.coded"/>
			</xsl:if>
		 </xsl:if>

		<!-- Segmento FTX-->
		<xsl:for-each select="IFTFCCI02.GROUP41/trsd_free.text">

	   		IFTI02031<xsl:text>^</xsl:text><xsl:value-of select="tred_text.subject.qualifier"/>
		    	<xsl:text>^</xsl:text><xsl:value-of select="trcd_text.literal/tred_free.text"/>		

		</xsl:for-each>	
		<!-- /GRUPO41 -->

	</xsl:for-each>
	<!-- /GRUPO37 -->

	<!-- GRUPO42 -->
	<xsl:for-each select="IFTFCCI02.GROUP42">

            <!-- Segmento EQD -->
		<xsl:variable name="equQual" select="trsd_equipment.details/tred_equipment.qualifier"/>
		<xsl:variable name="equId" select="trsd_equipment.details/tred_equipment.identification.number"/>
   		<xsl:variable name="equType" select="trsd_equipment.details/tred_equipment.size.and.type.identification"/>
	   	<xsl:variable name="Indicator" select="trsd_equipment.details/tred_full.empty.indicator.coded"/>

	   	<xsl:if test="trsd_equipment.details">
			IFTI02032<xsl:text>^</xsl:text>
		  	<xsl:value-of select="$equQual"/>
		  	<xsl:text>^</xsl:text>
		  	<xsl:value-of select="$equId"/>
		  	<xsl:if test="boolean($equType[text()] or $Indicator[text()])">
				<xsl:text>^</xsl:text><xsl:value-of select="$equType"/>
		  	</xsl:if>
		  	<xsl:if test="boolean($Indicator[text()])">
				<xsl:text>^</xsl:text><xsl:value-of select="$Indicator"/>
		  	</xsl:if>
		</xsl:if>

		<!-- Segmento TMD -->
		<xsl:variable name="movTypCo" select="trcd_movement.type/tred_movement.type.coded"/>
		<xsl:variable name="movTyp" select="trcd_movement.type/tred_movement.type"/>

		<xsl:if test="trcd_movement.type">
			IFTI02033
			<xsl:if test="boolean($movTypCo[text()] or $movTyp[text()])">
				<xsl:text>^</xsl:text><xsl:value-of select="$movTypCo"/>
		  	</xsl:if>
		  	<xsl:if test="boolean($movTyp[text()])">
				<xsl:text>^</xsl:text><xsl:value-of select="$movTyp"/>
		  	</xsl:if>

		</xsl:if>

		<!--Segmento MEA -->
		<xsl:if test="trsd_measurements">
			IFTI02034<xsl:text>^</xsl:text><xsl:value-of select="trsd_measurements/tred_measurement.application.qualifier"/>
			<xsl:text>^</xsl:text><xsl:value-of select="trsd_measurements/tred_measurement.dimension.coded"/>
			<xsl:text>^</xsl:text><xsl:value-of select="trsd_measurements/tred_measure.unit.qualifier"/>
			<xsl:text>^</xsl:text><xsl:value-of select="trsd_measurements/tred_measurement.value"/>
		</xsl:if>

		<!-- Segmento DIM  -->
		<xsl:variable name="calDim" select="trcd_dimensions/tred_dimension.qualifier"/>
		<xsl:variable name="meaQual" select="trcd_dimensions/tred_measure.unit.qualifier"/>
		<xsl:variable name="meaL" select="trcd_dimensions/tred_length.dimension"/>
		<xsl:variable name="meaW" select="trcd_dimensions/tred_width.dimension"/>
		<xsl:variable name="meaH" select="trcd_dimensions/tred_height.dimension"/>

		<xsl:if test="trcd_dimensions">
			IFTI02035<xsl:text>^</xsl:text><xsl:value-of select="$calDim"/>
			<xsl:text>^</xsl:text><xsl:value-of select="$meaQual"/>
		  	<xsl:if test="boolean($meaL[text()] or $meaW[text()] or $meaH[text()] )">
				<xsl:text>^</xsl:text><xsl:value-of select="$meaL"/>
		  	</xsl:if>
		  	<xsl:if test="boolean($meaW[text()] or $meaH[text()])">
				<xsl:text>^</xsl:text><xsl:value-of select="$meaW"/>
		  	</xsl:if>
	       	 	<xsl:if test="boolean($meaH[text()])">
				<xsl:text>^</xsl:text><xsl:value-of select="$meaH"/>
		  	</xsl:if>
		</xsl:if>

		<!-- Segmento SEL  -->
		<xsl:variable name="sealN" select="trsd_seal.number/tred_seal.number"/>

		<xsl:if test="trsd_seal.number">
			IFTI02036<xsl:text>^</xsl:text><xsl:value-of select="$sealN"/>
		</xsl:if>

		<!-- Segmento FTX-->

		<xsl:if test="trsd_free.text">
			IFTI02037<xsl:text>^</xsl:text><xsl:value-of select="trsd_free.text/tred_text.subject.qualifier"/>
			<xsl:text>^</xsl:text><xsl:value-of select="trsd_free.text/trcd_text.literal/tred_free.text"/>
		</xsl:if>

        <!-- Segmento RFF-->
        <xsl:variable name="rffQual" select="IFTFCCI02.GROUP43/trcd_reference/tred_reference.qualifier"/>
		<xsl:variable name="rffNum" select="IFTFCCI02.GROUP43/trcd_reference/tred_reference.number"/>
        <xsl:if test="boolean($rffQual[text()] or $rffNum[text()])">
            IFTI02038<xsl:text>^</xsl:text><xsl:value-of select="$rffQual"/>
            <xsl:text>^</xsl:text><xsl:value-of select="$rffNum"/>
        </xsl:if>

         </xsl:for-each>

        <!-- /GRUPO42 -->

   </xsl:template>
   <!--TANCO 28 -->
</xsl:stylesheet>